\name{angles}
\alias{angles}
\title{Compute Turning Angles}
\description{
  \code{angles} computes the turning angles (in radians) between
  consecutive moves from an object of class \code{traj}. See examples
  for a clearer definition.
}
\usage{
angles(x, id = levels(x$id), burst = levels(x$burst), date = NULL)
}
\arguments{
  \item{x}{an object of class \code{traj} }
  \item{id}{a character vector giving the identity of the animals for which
    the angles are to be computed}
  \item{burst}{a character vector giving the identity of the circuits for which
    the angles are to be computed (see \code{as.traj})}
  \item{date}{a vector of class \code{POSIXct} of length 2 (beginning, end)
    delimiting the period of interest}
}
\value{
  Returns a data frame with the following components:
  \item{id}{the identity of the animal}
  \item{x}{the x coordinate of the relocation at which the angle is computed}
  \item{y}{the y coordinate of the relocation at which the angle is computed}
  \item{date}{a vector of class \code{POSIXct}, giving the date at which
    the relocation has been taken}
  \item{burst}{the id of the circuit (see \code{help(as.traj)})}
  \item{angles}{the turning angles between the successive moves.}
}
\references{
  Turchin, P. (1998) \emph{Quantitative analysis of movement. Measuring
    and modeling population redistribution in animals and plants.}
  Sunderland, Massachusetts: Sinauer Associates.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{speed}} for computation of movement speeds,
  \code{\link{as.traj}} for additional information about objects of
  class \code{traj}  }
\examples{
## loads an object of class "traj"
data(puechcirc)
puechcirc

## Gets a part of the trajectory of the wild boar named
## CH93 and draws it
## Also displays the turning angles
toto <- puechcirc[2:5,]
plot(toto$x, toto$y, asp = 1, ylim = c(3158300, 3158550),
     pch = 16,
     main = "Turning angles between\nthree consecutive moves",
     xlab="X", ylab="Y")
lines(toto$x, toto$y)
lines(c(toto$x[2], 700217.6),
      c(toto$y[2], 3158310), lty=2)
lines(c(toto$x[3],700289),
      c(toto$y[3],3158546), lty=2)
ang1x <- c(700234.8, 700231.9, 700231, 700233.7, 700238.8, 700243.2)
ang1y <- c(3158332, 3158336, 3158341, 3158347, 3158350, 3158350)
ang2x <- c(700283.3, 700278.8, 700275.4, 700272.4, 700271.2, 700271.6,
           700274.7)
ang2y <- c(3158522, 3158522, 3158520, 3158517, 3158514, 3158508, 3158504)
lines(ang1x, ang1y)
lines(ang2x, ang2y)
text(700216.1, 3158349, expression(theta[1]), cex=2)
text(700247.7, 3158531, expression(theta[2]), cex=2)
text(c(700301, 700231), c(3158399, 3158487),
     c("Beginning", "End"), pos=4)



## Computation of the turning angles with real data
## on wild boars
plot(puechcirc)
ang <- angles(puechcirc)

## The angles are in the column Angles:
ang[1:4,]

}
\keyword{spatial}

\eof
\name{area2dxf}
\alias{area2dxf}
\title{Exportation of Areas}
\description{
\code{area2dxf} exports a data frame of class \code{area} in a DXF file.  Such
files can be read by virtually all Geographic Information Systems.
}
\usage{
area2dxf(x, file, lay = 1:nlevels(factor(x[, 1])))
}
\arguments{
  \item{x}{an object of class \code{area}}
  \item{file}{a character string giving the name of the DXF file to be
    created}
  \item{lay}{an optional vector with a length equal to the number of
    polygons in \code{x}. This vector is then stored in the field
    "Layer" of the DXF file (see examples), for GIS mapping}
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.area}}, \code{\link[ade4]{area.plot}}}
\examples{

\dontrun{
  ## Loads the dataset elec88 from the package ade4
  data(elec88)
  ar <- as.area(elec88$area)
  area.plot(ar, lab = elec88$lab, clab = 0.75)
  
  ## exportation of the departments toward a dxf file
  area2dxf(ar, file = "Dept", lay = elec88$lab)
  
  ## Removes the file
  file.remove("Dept.dxf")
}



}
\keyword{hplot}


\eof
\name{as.area}
\alias{as.area}
\title{Objects of Class "area"}
\description{
  Objects of class \code{area} are used to store the information on
  the shape of vectorised objects.\cr
  An object of class \code{area} is a data frame with three variables.
  The first variable is a factor defining the polygons.\cr
  The second and third variables are the xy coordinates of the
  polygon vertices in the order where they are found.  This kind
  of objects are current in the package \code{ade4}, though this package
  does not define \code{area} as a special class.
}
\usage{
as.area(x)
}
\arguments{
  \item{x}{a data frame with three columns}
}
\value{
  Returns an object of class \code{area}
}
\seealso{ \code{\link[ade4]{area.plot}} for other operations on
  objects of class \code{area}, \code{\link{area2dxf}} for exportation
  of the objects \code{area} toward a GIS. }
\examples{
data(elec88)
ar <- as.area(elec88$area)
area.plot(ar)
}
\keyword{spatial}

\eof
\name{as.kasc}
\alias{as.kasc}
\alias{kasc}
\alias{getkasc}
\alias{image.kasc}
\alias{print.kasc}
\title{Working with Several Raster Maps}
\description{
  \code{as.kasc} converts a list of matrices of class \code{asc} into a
  data frame of class \code{kasc}.\cr
  \code{getkasc} converts one of the components of a data frame of class
  \code{kasc} into a matrix of class \code{asc}.\cr
  \code{image.kasc} displays a image of maps of
  class \code{kasc}.
}
\usage{
as.kasc(l)
getkasc(x, var)
image.kasc(x, mar = c(0, 0, 2, 0), var = names(x), 
           axes = FALSE, clfac = NULL, col = gray((240:1)/256),
           mfrow = NULL, \dots)
print.kasc(x, \dots)
}

\arguments{
  \item{l}{a list of objects of class \code{asc}}
  \item{x}{an object of class \code{kasc}}
  \item{var}{for \code{getkasc}, a character string and for
    \code{image.kasc}, a vector of character strings, giving the name
    of one (or several) variable(s) in x }
  \item{mar}{this parameter is passed as the parameter \code{mar} of the
    function \code{par} (see \code{help(par)}).}
  \item{axes}{logical.  If \code{TRUE}, axes are drawn on the maps.}
  \item{clfac}{an optional list of vectors of character strings. Each
    element of the list is a vector corresponding to one factor in \code{x}.
    Each element of the vector gives the color name associated with each
    level of the corresponding factor (see Examples).}
  \item{col}{a character vector.  For numeric maps, the
    colors to be used}
  \item{mfrow}{A vector of the form \code{c(nr, nc)}. Subsequent
    figures will be drawn in an \code{nr}-by-\code{nc} array on the
    device by rows}
  \item{\dots}{additional parameters to be passed to the generic 
    functions \code{image} and \code{print}}
}
\value{
  \code{as.kasc} returns an object of class \code{kasc}.  The matrices
  of class \code{asc} are converted into vectors and coerced into a data
  frame of class \code{kasc}.  This data frame has the following
  attributes:
  
  \item{xll}{the X-coordinate of the center of the lower left
    pixel of the map}
  \item{yll}{the Y-coordinate of the center of the lower left
    pixel of the map}
  \item{cellsize}{the size of a pixel}
  \item{nrow}{the number of rows of the map.  Caution ! the number of
    rows of the raster map is the number of columns of the matrix of
    class \code{asc}}
  \item{ncol}{the number of columns of the map.  Caution ! the number of
    columns of the raster map is the number of rows of the matrix of
    class \code{asc}}

  The different maps in the input list of objects of class \code{asc}
  should describe the same area (same attributes: same \code{cellsize},
  same \code{xll}, same \code{yll}, and same dimensions). 
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{import.asc}} for additionnal information on
  objects of class \code{asc}}

\examples{

data(puechabon)

## kasc is a list of class kasc
(kasc <- puechabon$kasc)


## Stores two elements of the kasc in objects
## of class asc
(asp <- getkasc(kasc, "Aspect"))
(sl <- getkasc(kasc, "Slope"))


## Displays the slopes on the area (numeric)
image(sl, main = "Aspect", xlab = "Lambert X", ylab = "Lambert Y")


## Aspect is a factor:
## cl is the list of color associated with the levels
## of asp
cl <- colasc(asp, NorthEast = "blue", SouthEast = "red", 
             SouthWest = "orange", NorthWest = "green")
image(asp, clfac = cl, main = "Aspect", xlab = "Lambert X",
      ylab = "Lambert Y")
legend(706500, 3162000, legend=levels(asp), fill=cl, cex=0.7)



## Creation of a new kasc with elevation 
## and slopes
cuicui <- as.kasc(list(Slope = sl, Aspect = asp))

## Displays the kasc object
## with random colors for aspect and grey levels for slopes
image(cuicui)

## with cm.colors for slopes (numeric)
## and cl for aspect (factor)
image(cuicui, col = cm.colors(256), clfac = list(Aspect = cl))
}
\keyword{programming}
\keyword{hplot}

\eof
\name{as.sahrlocs}
\alias{as.sahrlocs}
\alias{getsahrlocs}
\alias{print.sahrlocs}
\title{Exploratory Analysis of Habitat Selection}
\description{
  \code{as.sahrlocs} creates objects of class \code{sahrlocs}.
  This class has a central place in habitat selection studies relying on
  radio-tracking data.  Niche analysis and K-select analysis can be
  performed using this class of objects.  This class may also be used
  for exploratory purposes.  This class of
  object has three main components: an object of class \code{kasc}
  describing the study area, an object of class \code{kasc} describing
  what is available to the animals, and an object of class \code{kasc}
  describing the relocations of the animals (\code{sahrlocs} = Study
  Area - Home Range - reLOCationS).  \code{getsahrlocs} converts one of the
  components of an object of class \code{sahrlocs} into an object of class
  \code{kasc}.
}
\usage{
as.sahrlocs(mlocs, mhr, msa, descan = NULL)
getsahrlocs(x, what = c("sa", "hr", "locs"))
print.sahrlocs(x, \dots)
}

\arguments{
  \item{mlocs}{an object of class \code{kasc} returned by the
    function \code{count.points.id}}
  \item{mhr}{an object of class \code{kasc} returned by the function
    \code{hr.rast}, by the function \code{buffer.ani}, or by any other
    user-defined function}
  \item{msa}{an object of class \code{kasc} describing the study area}
  \item{descan}{an optionnal data frame with the number of rows equal to
    the number of monitored animals.  Each column of this data frame
    gives any type of information on the monitored animals (e.g. sex,
    age, and so on)}
  \item{what}{a character string giving the component of the
    \code{sahrlocs} object to be
    converted.  Should be either \code{"sa"} (study area), \code{"hr"}
    (home ranges) or \code{"locs"} (relocations)}
  \item{x}{an object of class \code{sahrlocs}}
  \item{\dots}{additionnal parameters to be passed to the generic
    function \code{print}}
}
\details{
  The different maps in the input list of objects \code{kasc} should describe
  the same area (same attributes: same \code{cellsize}, same \code{xll},
  same \code{yll} and same dimensions).
}
\value{
  Returns one object of class \code{sahrlocs}, which is a list
  containing the input arguments for the function
  \code{as.sahrlocs}. Objects of class \code{sahrlocs} have the same
  attributes as objects of class \code{kasc} (\code{xll}, \code{yll},
  \code{cellsize}, \code{nrow}, and \code{ncol}).\cr
  
  \code{getsahrlocs} returns
  an object of class \code{kasc} (see \code{\link{as.kasc}}).
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{as.kasc}} for additionnal information on objects
  of class \code{kasc}, \code{\link{hr.rast}} and \code{\link{buffer.ani}}
  for the creation of the \code{"hr"}
  component of this object, \code{\link{count.points.id}} for the
  creation of the \code{"locs"} component of this
  object, \code{\link{plot.sahrlocs}} and \code{\link{image.sahrlocs}}
  for a graphical display of such objects. }

\examples{
data(puechabon)
kasc <- puechabon$kasc
locs <-  puechabon$locs

## Computes the home ranges of the animals...
cp <- mcp(locs[,4:5], locs[,1])

## ... and converts it to raster
cprast <- hr.rast(cp, kasc)
locrast <- count.points.id(locs[,4:5], locs[,1], kasc)

## Creation of the sahrlocs object
(sahr <- as.sahrlocs(locrast, cprast, kasc))

## adds information on the monitored animals
age <- factor(tapply(locs[,2], locs[,1], mean))
sex <- factor(tapply(locs[,3], locs[,1], mean))
info <- as.data.frame(cbind(sex, age))
(sahr <- as.sahrlocs(locrast, cprast, kasc, info))


## Gets the "study area" component of the object
toto <- getsahrlocs(sahr)
image(toto)
}
\keyword{spatial}
\keyword{multivariate}

\eof
\name{as.traj}
\alias{as.traj}
\alias{print.traj}
\alias{summary.traj}
\alias{plot.traj}
\alias{getburst}
\alias{traj2df}
\alias{df2traj}
\title{Working with Trajectories in 2D Space}
\description{
  The class \code{traj} is intended to explore trajectories of
  animals monitored using radio-tracking.\cr
  \code{as.traj} creates an object of this class.\cr
  \code{summary.traj} returns the number of relocations for each "burst"
  of relocations and each animal.\cr
  \code{plot.traj} allows various graphical displays of the
  trajectories.\cr
  \code{getburst} returns an object of class \code{traj} satisfying the
  specified criteria (selection of one focus animal, of a period of interest,
  of special "bursts" (see details)).\cr
  \code{traj2df}, and the reciprocal function \code{df2traj}
  respectively converts an object of class \code{traj} to an object of
  class \code{data.frame}, and conversely.
}
\usage{
as.traj(id, xy, date, burst = id, ...)
print.traj(x, ...)
summary.traj(object, id = levels(object$id), date = NULL, \dots)
plot.traj(x, id = levels(x$id), burst = levels(x$burst), date = NULL,
          asc = NULL, area = NULL,
          xlim = range(x$x), ylim = range(x$y),
          colasc = gray((256:1)/256), colpol = "green",
          addpoints = TRUE, addlines = TRUE,
          perani = TRUE, final = TRUE, \dots)
getburst(x, burst = levels(x$burst),
         id = levels(x$id), date = NULL)
traj2df(x)
df2traj(df)
}
\arguments{
  \item{id}{a factor giving for each relocation the
    identity of the individual monitored in \code{as.traj}. \cr
    a character vector containing the identity of the
    individuals of interest in other functions}
  \item{xy}{a data frame containing the coordinates of the relocations}
  \item{date}{a vector of class \code{POSIXct}
    giving the date for each relocation in \code{as.traj}.\cr
    a vector of class \code{POSIXct} with length 2, indicating the
    beginning and the end of the period of interest in other
    functions}
  \item{burst}{a factor giving the identity of each
    "burst" of relocations in \code{as.traj} (e.g. the circuit id, see
    details).  The burst level needs to be unique (two animals cannot
    have the same burst levels).  \cr
    a character vector containing the burst levels of interest in
    \code{plot.traj} and \code{getburst}} 
  \item{x}{an object of class \code{traj}}
  \item{object}{an object of class \code{traj}}
  \item{asc}{an object of class \code{asc}}
  \item{area}{an object of class \code{area} (see \code{help(area)})}
  \item{xlim}{the ranges to be encompassed by the x axis}
  \item{ylim}{the ranges to be encompassed by the y axis}
  \item{colasc}{a character vector giving the colors of the
    map of class \code{asc}}
  \item{colpol}{a character vector giving the colors of the
    polygon contour map, when \code{area} is not \code{NULL}}
  \item{addlines}{logical.  If \code{TRUE}, lines joining consecutive
    relocations are drawn}
  \item{addpoints}{logical.  If \code{TRUE}, points corresponding to
    each relocation are drawn}
  \item{perani}{logical.  If \code{TRUE}, one plot is drawn for each
    level of the factor \code{id}, and for a given animal, the several
    bursts are superposed on the same plot.  If \code{FALSE}, one plot
    is drawn for each level of the factor \code{burst}}
  \item{final}{logical. If \code{TRUE}, the initial and final
    relocations of each burst are indicated in blue and red, respectively}
  \item{df}{a data frame to be converted to the class \code{traj}} 
  \item{\dots}{other optional vectors containing some variables measured at
    each relocation (e.g. temperature, wind, 
    elevation, etc.) in \code{as.traj}.  \cr
    For other functions, arguments to be passed to
    the generic functions \code{plot}, \code{summary} and \code{print}}
}
\details{
  For a given individual, trajectories are often sampled as "bursts"
  of relocations (Dunn and Gipson, 1977).  For example,
  when an animal is monitored using radio-tracking, the data may consist
  of several circuits of activity (two successive relocations on one
  circuit are often highly autocorrelated, but the data from two
  circuits may be sampled at long intervals in time).  These bursts are
  indicated by the factor \code{burst}.
}
\value{
  An object of class \code{traj} is a data frame with one column
  named \code{id}, one column named \code{x}, one column named \code{y},
  one column named \code{date} and one column named \code{burst}.  This
  class therefore inherits from the class \code{data.frame}.
}
\references{
  Dunn, J.E. and Gipson, P.S. (1977) Analysis of radio telemetry data in
  studies of home range. \emph{Biometrics}. \bold{59}, 794--800.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{as.POSIXct}} and \code{\link{strptime}} for
  additional information of the class \code{POSIX}. }
\examples{

data(puechabon)
locs <- puechabon$locs
locs[1:4,]

### Conversion of the date to the format POSIX
da <- as.character(locs$Date)
da <- as.POSIXct(strptime(as.character(locs$Date),
               "\%y\%m\%d"))


### Creation of the object of class "traj"
(tr <- as.traj(id = locs$Name, xy = locs[,c("X", "Y")],
               date = da))
summary(tr)
plot(tr)

### Displays on maps of the study area
k <- puechabon$kasc
ele <- getkasc(k, "Elevation")
plot(tr, asc = ele)


### Case with several burst per animal
data(puechcirc)
plot(puechcirc, asc = ele)
plot(puechcirc, asc = ele, perani = FALSE)

}
\keyword{spatial}

\eof
\name{asc2im}
\alias{asc2im}
\alias{im2asc}
\title{Conversion of Maps of Class 'asc' and 'im' (Package spatstat)}
\description{
  These functions convert maps of class \code{asc} to objects of
  class \code{im} (package spatstats) and conversely.
}
\usage{
asc2im(x)
im2asc(x)
}
\arguments{
  \item{x}{an object of class \code{asc} or \code{im}}
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{import.asc}} for additionnal information on
  objects of class \code{asc}, and \code{\link[spatstat]{im}} for
  additionnal information on objects of class \code{im}}
\examples{
if (require(spatstat)) {
  
#######################
### Conversion asc -> im

  data(puechabon)
  el <- getkasc(puechabon$kasc, "Elevation")
  image(el, main = "An object of class \"asc\"")
  elim <- asc2im(el)
  image(elim, main = "An object of class \"im\"")

#######################
### Conversion im -> asc
  u <- matrix(rnorm(10000), 100, 100)
  haha <- im(u)
  image(haha, main = "class im")
  hihi <- im2asc(haha)
  image(hihi, main = "class asc")

}
}
\keyword{spatial}


\eof
\name{ascgen}
\alias{ascgen}
\title{Creation of Raster Maps}
\description{
  \code{ascgen} creates an object of class \code{asc} using
  a set of points.
}
\usage{
ascgen(xy = NULL, cellsize = NULL, nrcol = 10, count = TRUE)
}

\arguments{
  \item{xy}{a data frame with two columns: the x and y coordinates of the
    points}
  \item{cellsize}{the \code{cellsize} attribute
    of the object of class \code{asc} to be created}
  \item{nrcol}{the size of the square raster map to
    be created (number of rows and columns)}
  \item{count}{logical.  If \code{TRUE}, the object of class \code{asc}
    contains the number of points in each cell.  If \code{FALSE}, all
    the cells are set to zero} 
}
\value{
  Returns an object of class \code{asc}.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{\code{\link{import.asc}} for additional information on objects
  of class \code{asc}.}

\examples{
data(puechabon)
lo <- puechabon$locs[,c("X","Y")]
plot(lo, asp = 1, pch = 16)

## lo contains the relocations of wild boars
rast <- ascgen(lo, cellsize = 100)
image(rast)

## Alternatively, one can specify the size of the square raster map
rast <- ascgen(lo, nrcol = 10)
rast
image(rast)

## can be used for further analyses
## (e.g. correspondence analyses)
locs <- puechabon$locs[, c("Name", "X", "Y")]
o <- count.points.id(locs[,2:3], locs[,1], rast)
image(o)
}
\keyword{spatial}

\eof
\name{bighorn}
\docType{data}
\alias{bighorn}
\title{ Radio-Tracking of Bighorn Sheeps}
\description{
This data set describes the habitat use and availability for 6 bighorn
sheeps monitored by radio-tracking (Arnett et al. 1989, in Manly et al.,
2003, p. 67-74). 10 habitat types are considered.
}
\usage{
data(bighorn)
}
\details{
  The object \code{bighorn} is a list, with the following components:
  \describe{
  \item{\code{used}}{the number of resource units used by each animal (in rows)
    in each habitat category (in columns).}
  \item{\code{availTrue}}{the availability of each habitat category.}
  \item{\code{availEstimated}}{a sample of available resource units in each
    habitat category.}
  }
}
\references{
  Manly, B.F.J., McDonald, L.L., Thomas, D.L., McDonald, T.L. & Erickson,
  W.P. (2003) \emph{Resource selection by animals - Statistical design and
    Analysis for field studies. Second edition.}
  London: Kluwer academic publishers. 
}
\keyword{datasets}

\eof
\name{biv.test}
\alias{biv.test}
\title{Bivariate Test}
\description{
  \code{biv.test} displays the results of a bivariate randomisation test.
}
\usage{
biv.test(dfxy, point, cbreaks = 8, h, colD = "blue", colP = "orange",
         o.include = FALSE, rem = NULL, \dots) 
}
\arguments{
  \item{dfxy}{a data frame with N lines (couples of values) and two
    columns}
  \item{point}{a vector of length 2, representing
    the observation to be compared with the simulated values of the
    randomisation test}
  \item{cbreaks}{a parameter used to define the numbers of breaks of the
    histograms.  A larger value leads to a larger number of breaks}
  \item{h}{vector of bandwidths for x and y directions, used in the
    function \code{kde2d} of the package \code{MASS}.  Defaults to normal
    reference bandwidth (see \code{?kde2d})}
  \item{colD}{a color used for the contours}
  \item{colP}{a color used for the observation}
  \item{o.include}{logical.  If \code{TRUE}, the origin is included in
    the plot}
  \item{rem}{a character string to be inserted in the plot}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
  \code{biv.test} is used to display the results of a bivariate
  randomisation test.  An example of use of the function is provided in
  the function \code{niche.test}.
  
  The x-axis of the main window corresponds to the first column of
  \code{dfxy}; the y-axis corresponds to the second column.  Kernel
  density is estimated to indicate the contours of the distribution of
  randomised values.  The two marginal histograms correspond to the
  univariate tests on each axis, for which the p-values are computed with
  \code{as.randtest} (one-sided tests).
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr}}
\section{Warning}{
  \code{biv.test} uses the function \code{kde2d} of the package
  \code{MASS}.
}
\seealso{
  \code{\link[ade4]{as.randtest}}, \code{\link{niche.test}}
}
\examples{
\dontrun{
if (require(MASS)) {
  dfxy <- data.frame(x = rnorm(1000,5), y = rnorm(1000,5))
  p <- c(3.5, 3.5)
  biv.test(dfxy, p, rem = "Bivariate\nnormal distribution")
}
}
}
\keyword{multivariate}

\eof
\name{buffer}
\alias{buffer}
\alias{buffer.ani}
\title{Compute Buffers}
\description{
  \code{buffer} compute buffers around a set of
  locations. \cr
  \code{buffer.ani} is to be used when the
  points can be grouped into several categories  (e.g. the relocations
  of several animals monitored using radio-tracking; the function
  \code{buffer} is then applied to each animal).
}
\usage{
buffer(pts, x, dist)
buffer.ani(pts, fac, x, dist)
}

\arguments{
  \item{pts}{a data frame with two columns (x and y coordinates of the
    points)}
  \item{x}{either an object of class \code{asc} or \code{kasc} with the same
    attributes as those desired for the output, or an object of class
    \code{mapattr} (see \code{storemapattr})}
  \item{dist}{a value of distance}
  \item{fac}{a factor defining the categories of the points}
}
\value{
  \code{buffer} returns an object of class \code{asc}, with 1 for pixels
  located within a specified distance of given points, and \code{NA}
  otherwise.\cr 
  \code{buffer.ani} returns a data frame of class \code{kasc},
  with each column corresponding to one level of the factor \code{fac}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.kasc}} for additionnal information on
  objects of class \code{kasc}, \code{\link{import.asc}} for further
  information on objects of class \code{asc}, \code{\link{storemapattr}}
  for further information on objects of class \code{mapattr}.
}

\examples{
data(puechabon)

# locs is the data frame containing the
# relocations of wild boars monitored by radio-tracking 
locs <- puechabon$locs

# sa is the "kasc" object of maps of the study area
sa <- puechabon$kasc

# Buffer of 500 m around all relocations
bu <- buffer(locs[,4:5], sa, 500)
image(bu)

# displays all the pixels of the study area within 500 m
# of a relocation of each monitored wild boar
buani <- buffer.ani(locs[,4:5], locs[,1], sa, 500)
image(buani)
 
}
\keyword{spatial}

\eof
\name{chamois}
\docType{data}
\alias{chamois}
\title{Location of Chamois Groups in the Chartreuse Mountains}
\description{
  This data set describes the habitat use and availability by the
  chamois of the Chartreuse mountains (Isre, France), in 1992 and 1997.
  These data have been gathered during the hunting season (Fall).
}
\usage{
data(chamois)
}
\details{
  The object \code{chamois} is a list containing the following
  components:
  \describe{
    \item{\code{locs}}{A data frame containing the x and y coordinates
      of 198 chamois groups.}
    \item{\code{map}}{a map of class \code{kasc} describing the
      vegetation (Forest or Open areas), the
      distance from the ecotone Open/Forest and the slopes on the
      area.}
    }
}
\references{
  Fdration Dpartementale des Chasseurs de l'Isre,
  65 av Jean Jaurs, 38320 Eybens. France.
}
\keyword{datasets}

\eof
\name{colasc}
\alias{colasc}
\title{Creates a Vector of Colors for a Raster Map of Type 'factor' }
\description{
  \code{colasc} creates a vector of colors for a raster map of class
  \code{asc} and of type \code{"factor"}. 
}
\usage{
colasc(x, \dots)
}

\arguments{
  \item{x}{an object of class \code{asc}. }
  \item{\dots}{arguments named as the levels of the factor, with
    character values equal 
    to the colors for these levels (see examples)}

}
\value{
  Returns a character vector.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{import.asc}} }

\examples{
data(puechabon)

## gets the aspect in an asc object
asp <- getkasc(puechabon$kasc, "Aspect")

## creates the vector of colors
cl <- colasc(asp, NorthEast = "blue", SouthEast = "red", 
             SouthWest = "orange", NorthWest = "green")

## graphical display
image(asp, clfac = cl, main = "Aspect", xlab = "Lambert X",
      ylab = "Lambert Y")
legend(706500, 3162000, legend=levels(asp), fill = cl, cex = 0.7)
 
}
\keyword{programming}

\eof
\name{compana}
\alias{compana}
\alias{print.compana}
\title{Compositional Analysis of Habitat Use}
\description{
\code{compana} performs a classical compositional analysis of habitat
use (Aebischer et al., 1993).
}
\usage{
compana(used, avail, test = c("randomisation", "parametric"),
        rnv = 0.01, nrep = 500, alpha = 0.1)
}
\arguments{
  \item{used}{a matrix or a data frame giving the percentage of use
    of habitats (in columns) by animals (in rows). }
  \item{avail}{a matrix or a data frame describing the percentage of
    availability of habitats (in columns) by animals (in rows). }
  \item{test}{a character string.  If \code{"randomisation"},
    randomisation tests are performed for
    both the  habitat ranking and
    the test of habitat selection.
    If \code{"parametric"}, usual
    parametric tests are performed (chi-square for the test of habitat
    selection and t-tests for habitat ranking).}
  \item{rnv}{the number replacing the 0 values occurring in the
    matrix \code{used}. }
  \item{nrep}{the number of repetitions in the
    randomisation tests. }
  \item{alpha}{the alpha level for the tests. }
}
\details{
  The compositional analysis of habitat use has been recommended by
  Aebischer et al. (1993) for the analysis of habitat selection by
  several animals, when the resources are defined by several categories
  (e.g. vegetation types).\cr
  This analysis is carried out in two steps: first the significance of
  habitat selection is tested (using a Wilks lambda). Then, a ranking
  matrix is built, indicating whether the habitat type in row is
  significantly used more or less than the habitat type in column.
  When this analysis is performed on radio-tracking data, Aebischer et
  al. recommend to study habitat selection at two scales: (i) selection
  of the home range within the study area, and (ii) selection of the
  relocations within the home range.  The first scale is termed
  second-order habitat selection by Johnson (1980), and the second,
  third-order habitat selection.\cr

  When zero values are found
  in the matrix of used habitats, they are replaced by a small value (by
  default, 0.01), according to the recommendations of Aebischer et al.
  (1993).\cr

  When zero values are found in the matrix of available habitats, the
  function \code{compana} uses the procedure termed
  "weighted mean lambda" described in Aebischer et al.
  (1993: Appendix 2), instead of the usual lambda (see examples). Zero
  values can be found in the matrix of available habitats when the
  third-order habitat selection is under focus. In this case, it may
  occur that some habitat types are available to some animals and not to
  the others.
}
\value{
  Returns a list of the class \code{compana}:
  \item{used}{the matrix of used habitats}
  \item{avail}{the matrix of available habitats}
  \item{type.test}{a character string.  Either \code{"randomisation"} or
    \code{"parametric"}}
  \item{test}{the results of the test of habitat selection}
  \item{rm}{the ranking matrix: a square matrix with \code{nh} rows and
    \code{nh} columns, where \code{nh} is the number of habitat types
    under study.  At the intersection of the row \code{i} and of the
    column \code{j}, there is a \code{"+"} when the habitat \code{i} is
    more used than the habitat in column, and \code{"-"} otherwise.
    When the difference is significant, the sign is tripled.}
  \item{rmnb}{the matrix containing the number of animals used to
    perform the tests in \code{rm}.}
  \item{rank}{the rank of the habitat types.  It is equal to the number
    of \code{"+"} for each habitat type in row of \code{rm}.}
  \item{rmv}{the matrix of statistics used to build \code{rm}.
    if \code{(test = "parametric")}, the matrix contains the
    values of \code{t}, in the t-test comparing the row and the column
    habitat.  if \code{(test = "randomisation")}, the matrix contains
    the mean difference between the used and available log-ratios (see
    Aebischer et al., 1993).}
  \item{profile}{The profile of preferences: resource types are sorted
    so that the left type is the most preferred and the right type is
    the most avoided.  Habitats for which the intensity of habitat
    selection is similar (no significant difference) are connected by a
    line.}
}
\references{
Aebischer, N. J. and Robertson, P. A. (1992) Practical aspects of
compositional analysis as applied to pheasant habitat
utilisation. pp. 285--293 In: Priede, G. and Swift, S. M. \emph{Wildlife
  telemetry, remote monitoring and tracking of animals}. 

Aebischer, N. J., Robertson, P. A. and Kenward, R. E. (1993)
Compositional analysis of habitat use from animal radiotracking
data. \emph{Ecology}, \bold{74}, 1313--1325.

Johnson, D. H. (1980) The comparison of usage and availability
measurements for evaluating resource preference. \emph{Ecology}, \bold{61},
65--71.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\note{
In the examples below, the results differ from those published in
Aebischer et al. (squirrel example, selection of the relocations within
the home range). In fact, there has been a confusion in the column names
in the paper. Actually, Aebischer (pers. com.) indicated that the
ranking matrix given in this example is correct.
}
\seealso{ \code{\link{wiII}} and \code{\link{wiIII}}
  for other analyses of habitat selection 
  with this kind of data. }

\examples{

## The examples presented here
## are the same as those presented in
## the paper of Aebischer et al. (1993)


#############################
## Pheasant dataset: first
## example in Aebischer et al.

data(pheasant)

## Second order habitat selection
## Selection of home range within the
## study area (example of parametric test)
pheana2 <- compana(pheasant$mcp, pheasant$studyarea,
                   test = "parametric")
pheana2

## The ranking matrix:
print(pheana2$rm, quote = FALSE)

## Third order habitat selection
## (relocation within home range)
## We remove the first pheasant of the analysis
## (as in the paper of Aebischer et al.)
## before the analysis
pheana3 <- compana(pheasant$locs[-1,], pheasant$mcp[-1,c(1,2,4)])
pheana3

## The ranking matrix:
print(pheana3$rm, quote = FALSE)



#############################
## Squirrel data set: second
## example in Aebischer et al.

data(squirrel)

## Second order habitat selection
## Selection of home range within the
## study area
squiana2 <- compana(squirrel$mcp, squirrel$studyarea)
squiana2

## The ranking matrix:
print(squiana2$rm, quote = FALSE)

## Third order habitat selection
## (relocation within home range)
## We remove the second column
## (as in the paper of Aebischer et al.)
squiana3 <- compana(squirrel$locs[,-2], squirrel$mcp[,-2])
squiana3

## The ranking matrix:
print(squiana3$rm, quote = FALSE)


}
\keyword{math}

\eof
\name{convnum}
\alias{convnum}
\title{Conversion from Factor to Numeric for Raster Map}
\description{
The objects of class \code{kasc} may contain maps of type \code{"numeric"}
(e.g. the elevation) or of type \code{"factor"} (e.g. the type of
vegetation).  \code{convnum} centres and scales the maps of type
\code{"numeric"}, and factor maps are transformed into a collection of k
maps of type \code{"numeric"} (where k is the number of levels of the
factor), with zero means and unit variance (see \code{dudi.mix} in the
\code{ade4} package for further details).
}
\usage{
convnum(kasc)
}
\arguments{
  \item{kasc}{an object of class \code{kasc}}
}
\value{
  Returns a list with the following components:
  \item{kasc}{an object of class \code{kasc}}
  \item{weight}{the weights associated with
    each map of the object kasc, so that the collection of maps defining
    a categorical variable has the same weight that a numeric variable
    (see examples).} 
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{\code{\link[ade4]{dudi.mix}}, \code{\link{as.kasc}}}
\examples{

## loads the data
data(puechabon)
kasc <- puechabon$kasc
image(kasc)

## scales all the variables
toto <- convnum(kasc)
image(toto$kasc)

## the Aspect has four levels:
## four variables have been defined.
toto$weight

## The sum of the weights given to each
## level of aspect is equal to:
toto$weight[2:5]
sum(toto$weight[2:5])

## The same weight is therefore given to the factor variable Aspect and
## to any continuous variable, e.g. the elevation.

}
\keyword{manip}


\eof
\name{count.points.id}
\alias{count.points.id}
\alias{count.points}
\title{Number of Points in Each Pixel of a Raster Map}
\description{
  \code{count.points} counts the number of points in
  each pixel of a raster map of class \code{kasc} or \code{asc}.\cr
  \code{count.points.id} counts the number of points falling in
  each pixel of a raster map of class \code{kasc} or \code{asc}, for
  different sets of points (e.g. the relocations of several animals
  monitored using radio-tracking) 
}
\usage{
count.points(xy, w)
count.points.id(xy, id, w)
}
\arguments{
  \item{xy}{a data frame containing the x and y coordinates of the points.}
  \item{id}{a factor giving, for each point, the membership of a point
    to a set.}
  \item{w}{an object of class \code{asc}, \code{kasc} or \code{mapattr}.}
}
\value{
  \code{count.points} returns an object of class \code{asc}
  containing the number of points in each cell of the raster
  map.\cr
  \code{count.points.id} returns an object of class \code{kasc},
  with one column per level of the factor \code{id},
  containing the number of points numbered in each cell of the raster
  map.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.kasc}} for additionnal information on objects
  of class \code{kasc}, and \code{\link{storemapattr}} for further
  information on objects of class \code{mapattr}.}

\examples{
data(puechabon)
kasc <- puechabon$kasc
locs <-  puechabon$locs

## Counts the number of relocations of each wild boar
## per pixel of the raster map
(nlocrast <- count.points.id(locs[,4:5], locs[,1], kasc))
image(nlocrast)

## Counts the number of all relocations
## per pixel of the raster map
(nlocrast <- count.points(locs[,c("X","Y")], kasc))
image(nlocrast)

}
\keyword{spatial}

\eof
\name{domain}
\alias{domain}
\title{Estimation of the Potential Distribution of a Species }
\description{
\code{domain} uses the DOMAIN algorithm to estimate the potential
distribution of a species based on a list of species occurrences and on
maps of the area.
}
\usage{
domain(kasc, pts, type = c("value", "potential"), thresh = 0.95)
}
\arguments{
  \item{kasc}{an object of class \code{kasc}}
  \item{pts}{a data frame giving the x and y coordinates of the species
    occurrences.}
  \item{type}{a character string. The \code{"value"} of the suitability
    may be returned 
    or the \code{"potential"} area of distribution}
  \item{thresh}{if \code{value = "potential"}, a threshold value should be
    supplied for the suitability (by default 0.95)}
}
\details{
  This function implements the DOMAIN algorithm described in Carpenter
  et al. (1993).
}
\value{
  Returns a matrix of class \code{asc}.
}
\section{Warning }{
  \code{domain} is restricted to maps
  containing only numerical variables (i.e. no factors).
}
\references{
  Carpenter, G., Gillison, A.N. and Winter, J. (1993)
  DOMAIN: a flexible modelling
  procedure for mapping potential distributions of plants and
  animals. \emph{Biodiversity and conservation}, \bold{2}, 667--680.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.kasc}} for additionnal information on objects
  of class \code{kasc}, \code{\link{import.asc}} for information on
  matrices of class \code{asc}.  }

\examples{

## Preparation of the data
data(puechabon)
kasc <- puechabon$kasc
kasc$Aspect <- NULL
pts <- puechabon$locs[puechabon$locs$Name == "Brock", 4:5]

## View of the data
elevation <- getkasc(kasc, "Elevation")
image(elevation)
points(pts, col = "red", pch = 16)

## Estimation of habitat suitability map
hsm <- domain(kasc, pts)
image(hsm, col = grey((1:256)/256))
contour(hsm, add = TRUE)
## Lighter areas are the most preferred areas

## Potential distribution
hsm <- domain(kasc, pts, type = "potential")
image(elevation, main = "Habitat suitability map")
image(hsm, add = TRUE, col = "orange")
points(pts, col = "red", pch = 16)

}
\keyword{spatial}
\keyword{multivariate}

\eof
\name{enfa}
\alias{enfa}
\alias{hist.enfa}
\alias{print.enfa}
\title{Ecological-Niche Factor Analysis}
\description{
  \code{enfa} performs an Ecological-Niche Factor Analysis.\cr
  \code{hist.enfa} draws histograms of the row scores or of the initial
  variables of the ENFA. 
}
\usage{
enfa(kasc, pts, scannf = TRUE, nf = 1)
hist.enfa(x, scores = TRUE, type = c("h", "l"),
          adjust = 1, colZ = "blue", colS = "orange", \dots) 
}
\arguments{
  \item{kasc}{a raster map of class \code{kasc}}
  \item{pts}{a data frame with two columns, giving the coordinates of
    the species locations}
  \item{scannf}{logical.  Whether the eigenvalues bar plot should be displayed}
  \item{nf}{if \code{scannf = FALSE}, an integer indicating the number of kept
    specialization axes }
  \item{x}{an object of class \code{enfa}}
  \item{scores}{logical.  If \code{TRUE}, the histograms display
    the row scores of the ENFA.  If \code{FALSE}, they display the
    environmental variables (in this case, this is equivalent to
    \code{histniche})}
  \item{type}{what type of plot should be drawn.  Possible types are:\cr
    * \code{"h"} for histograms,\cr
    * \code{"l"} for kernel density estimates (see \code{?density}).\cr
    By default, \code{type = "h"} is used.  If \code{type = "l"} is used,
    the position of the mean of each distribution is indicated by dotted
    lines}
  \item{adjust}{if \code{type = "l"}, a parameter used to control the
    bandwidth of the density estimates (see \code{?density})}
  \item{colZ}{color for the histograms of the available pixels}
  \item{colS}{color for the histograms of the used pixels}
  \item{\dots}{further arguments passed to or from other methods }
}
\details{
  The niche concept, as defined by Hutchinson (1957), considers the
  ecological niche of a species as an hypervolume in the multidimensional
  space defined by environmental variables, within
  which the populations of a species can persist.  The Ecological-Niche
  Factor Analysis (ENFA) has been developped by Hirzel et al. (2002) to
  analyse the position of the niche in the ecological space.  Nicolas
  Perrin (1984) described the position of the niche in the n-dimensional
  space using two measures: the M-specialization (hereafter termed marginality)
  and the S-specialization (hereafter termed specialization).  The
  marginality represents the squared distance of the niche barycentre from
  the mean available habitat.  A large specialization corresponds to a
  narrow niche relative to the habitat conditions available to the species.\cr

  The ENFA first extracts an axis of marginality (vector from the average
  of available habitat conditions to the average used habitat conditions).
  Then the analysis extracts successives orthogonal axes (i.e. uncorrelated),
  which maximises the specialization of the species.  The calculations
  used in the function are described in Hirzel et al. (2002).
}
\value{
  \code{enfa} returns a list of class \code{enfa} containing the
  following components: 
  \item{call}{original call.}
  \item{tab}{a data frame with n rows and p columns.}
  \item{pr}{a vector of length n containing the number of points in each
    pixel of the map.}
  \item{nf}{the number of kept specialization axes.}
  \item{m}{the marginality (squared length of the marginality vector).}
  \item{s}{a vector with all the eigenvalues of the analysis.}
  \item{lw}{row weights, a vector with n components.}
  \item{li}{row coordinates, data frame with n rows and nf columns.}
  \item{l1}{row normed scores, data frame with n rows and nf columns.}
  \item{co}{column coordinates, data frame with p rows and nf columns.}
  \item{c1}{column normed scores, data frame with p rows and nf columns.}
  \item{index}{an integer vector giving the position of the rows of
    \code{tab} in the  initial object of class \code{kasc}.}
  \item{attr}{an object of class \code{mapattr} with the attributes of the
    initial \code{kasc}.} 
}
\references{
  Hutchinson, G.E. (1957) Concluding Remarks. \emph{Cold Spring Harbor
  Symposium on Quantitative Biology}, \bold{22}: 415--427. 
  
  Perrin, N. (1984) Contribution  l'cologie du genre Cepaea
  (Gastropoda) : Approche descriptive et exprimentale de l'habitat et
  de la niche cologique. Thse de Doctorat. Universit de Lausanne,
  Lausanne. 
  
  Hirzel, A.H., Hausser, J., Chessel, D. & Perrin, N. (2002)
  Ecological-niche factor analysis: How to compute habitat-suitability
  maps without absence data? \emph{Ecology}, \bold{83}, 2027--2036.  
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr} }

\seealso{
  \code{\link[ade4]{niche}}, \code{\link{kselect}} for other types of
  analysis of the niche, when several species are under studies,
  \code{\link{niche.test}} to perform a test of the marginality and the
  tolerance of the niche, and \code{\link{scatter.enfa}} to have a
  graphical display of objects of class \code{enfa}.
}
\examples{
\dontrun{
data(lynxjura)

map <- lynxjura$map

## We keep only "wild" indices.
tmp <- lynxjura$locs[,4]!="D"
locs <- lynxjura$locs[tmp, c("X","Y")]
hist(map, type = "l")
## The variable artif is far from symetric

## We perform a square root transformation
## of this variable
## We therefore normalize the variable 'artif'
map[,4] <- sqrt(map[,4])
hist(map, type = "l")

## We perform the ENFA
(enfa1 <- enfa(map, locs[tmp, c("X","Y")],
               scannf = FALSE))
hist(enfa1)
hist(enfa1, scores = FALSE, type = "l")

## randomization test
(renfa <- randtest(enfa1))
plot(renfa)
if (require(MASS))
   scatter(enfa1)
}
}
\keyword{multivariate}

\eof
\name{getXYcoords}
\alias{getXYcoords}
\title{Computes the X and Y Coordinates of the Pixels of a Raster Map}
\description{
  \code{getXYcoords} computes the geographical coordinates of the rows
  and columns of pixels of a raster map.
}
\usage{
getXYcoords(w)
}
\arguments{
  \item{w}{an object of class \code{asc}, \code{kasc}, \code{sahrlocs},
    or \code{mapattr}.}
}
\value{
  Returns a list with two components:
  \item{x}{the x coordinates of the columns of pixels of the map}
  \item{y}{the y coordinates of the rows of pixels of the map}
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{ \code{\link{import.asc}}, \code{\link{as.kasc}},
  \code{\link{as.sahrlocs}}, \code{\link{storemapattr}}}

\examples{
data(puechabon)
(elev <- getkasc(puechabon$kasc, "Elevation"))
(coords <- getXYcoords(elev))
nrow(elev) == length(coords$x)
ncol(elev) == length(coords$y)
}
\keyword{programming}



\eof
\name{getascattr}
\alias{getascattr}
\alias{getkascattr}
\title{Copy the Attributes of an Object of Class 'asc' or 'kasc'
  to another Object }
\description{
  \code{getascattr} copies the attributes of an object of class \code{asc}
  to another matrix of the same size.\cr
  \code{getkascattr} performs the same operation for objects of class
  \code{kasc}.
}
\usage{
getascattr(xfrom, xto, type = c("numeric", "factor"), lev = NULL)
getkascattr(xkfrom, xkto)
}

\arguments{
  \item{xfrom}{an object of class \code{asc}}
  \item{xto}{a matrix with the same number of rows and columns
    as \code{xfrom}}
  \item{type}{a character string giving the type of the map
    (\code{"factor"} for maps of categorical 
    variables, and \code{"numeric"} otherwise)}
  \item{lev}{if \code{type = "factor"},
    a character vector giving the levels of the mapped variable
    (see \code{help(import.asc)})}
  \item{xkfrom}{an object of class \code{kasc}}
  \item{xkto}{a data frame with the same number of rows and columns
    as \code{xkfrom}}
}
\value{
  \code{getascattr} returns a raster matrix of class \code{asc},\cr
  \code{getkascattr} returns a data frame of class \code{kasc}
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{import.asc}}, \code{\link{as.kasc}} }

\examples{
data(puechabon)

## my.map is a map of elevation
my.map <- getkasc(puechabon$kasc, "Elevation")
sl <- getkasc(puechabon$kasc, "Slope")
attributes(sl) <- NULL
sl <- matrix(sl, ncol = ncol(my.map))

## sl is a matrix with the same size as my.map
toto <- getascattr(my.map, sl)
image(toto)

## same rationale with aspect
asp <- getkasc(puechabon$kasc, "Aspect")
le <- levels(asp)
attributes(asp) <- NULL
asp <- matrix(asp, ncol = ncol(my.map))

## asp is now a matrix with the same size as my.map
tutu <- getascattr(my.map, asp, typ = "factor", lev = le)
cl <- colasc(tutu, NorthEast = "blue", SouthEast = "red", 
           SouthWest = "orange", NorthWest = "green")
image(tutu, clfac = cl)

}
\keyword{programming}

\eof
\name{getcontour}
\alias{getcontour}
\title{Computes the Contour Polygon of a Raster Object}
\description{
  \code{getcontour} computes the contour polygon of a raster object
  of class \code{asc}.  When the object is made of several parts, the
  function returns one polygon per part.
}
\usage{
getcontour(x)
}

\arguments{
  \item{x}{an object of class \code{asc}}
}
\value{
  Returns an object of class \code{area}.
}
\section{Warning }{
  Holes in the polygons are not taken into account by the function.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{import.asc}} for additionnal information on
  objects of class \code{asc}, \code{\link{as.area}} for
  information on objects of class \code{area}, and
  \code{\link{area2dxf}} to export the results toward a GIS.}

\examples{

data(puechabon)
kasc <- puechabon$kasc

#########################################
## Example with one object:
## Gets the first map of the "kasc" object
## Map of the elevation
elev <- getkasc(kasc, "Elevation")
image(elev)
 
## Get the contour polygon
cpol <- getcontour(elev)

## Draw the polygon
i <- cpol[,2:3]
polygon(i, col = "green", lwd = 2)

#########################################
## Example with two objects:
## home ranges of wild boar

hr <- getsahrlocs(puechabon$sahr, "hr")
u <- getkasc(hr, "Jean")
image(u)

## Get the contour polygons
p <- getcontour(u)
area.plot(p, lwd = 2)

}
\keyword{programming}
\keyword{hplot}

\eof
\name{hist.kasc}
\alias{hist.kasc}
\title{Histograms of Mapped Variables}
\description{
\code{hist.kasc} performs histograms of the variables mapped in objects
of class \code{kasc}.
}
\usage{
hist.kasc(x, type = c("h", "l"), adjust = 1, col = "blue", \dots)
}
\arguments{
  \item{x}{a raster map of class \code{kasc} }
  \item{type}{what type of plot should be drawn.  Possible types are:\cr
    * \code{"h"} for histograms,\cr
    * \code{"l"} for kernel density estimates (see \code{?density}).\cr
    By default, \code{type = "h"} is used.  If \code{type = "l"} is used,
    the position of the mean of each distribution is indicated by dotted
    lines}
  \item{adjust}{if \code{type = "l"}, a parameter used to control the
    bandwidth of the density estimate (see \code{?density})}
  \item{col}{color for the histogram}
  \item{\dots}{further arguments passed to or from other methods}
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr}}
\seealso{\code{\link{as.kasc}}}
\examples{

## Example with factors and numeric variables
data(puechabon)
hist(puechabon$kasc)

## Removing the factor Aspect, and smoothing gives :
hist(puechabon$kasc[,-2], type = "l")

}
\keyword{hplot}


\eof
\name{histniche}
\alias{histniche}
\title{Histograms of the Ecological Niche of a Species}
\description{
  \code{histniche} draws histograms of the variables mapped in an
  object of class \code{kasc} (habitat available for the species). The
  histograms of the habitat used by a species (i.e. the niche) are
  computed from the locations of the focus species, and are added to the
  plot of available habitat for each variable, for comparison.
}
\usage{
histniche(kasc, pts, type = c("h", "l"), adjust = 1,
          colZ = "blue", colS = "orange", \dots)
}
\arguments{
  \item{kasc}{a raster map of class \code{kasc}}
  \item{pts}{a data frame with two columns, giving the coordinates of
    the species locations}
  \item{type}{what type of plot should be drawn.  Possible types are:\cr
    * \code{"h"} for histograms,\cr
    * \code{"l"} for kernel density estimates (see \code{?density}).\cr
    By default, \code{type = "h"} is used.  If \code{type = "l"} is used,
    the position of the mean of each distribution is indicated by dotted
    lines}
  \item{adjust}{if \code{type = "l"}, a parameter used to control the
    bandwidth of the density estimate (see \code{?density})}
  \item{colZ}{color for the histograms of the available pixels}
  \item{colS}{color for the histograms of the used pixels}
  \item{\dots}{further arguments passed to or from other methods}
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr} }
\examples{
\dontrun{
## Example with factors and numeric variables
data(puechabon)
histniche(puechabon$kasc, puechabon$locs[, c("X", "Y")])
histniche(puechabon$kasc, puechabon$locs[, c("X", "Y")], type = "l")
}
}
\keyword{multivariate}

\eof
\name{hr.rast}
\alias{hr.rast}
\title{Rasterisation of Objects of Class 'area'}
\description{
Converts an object of class \code{area} (used in many functions of the
package \code{ade4}) to an object of class \code{kasc} (rasterisation).
}
\usage{
hr.rast(mcp, w)
}

\arguments{
  \item{mcp}{an object of class \code{area}}
  \item{w}{a raster map of class \code{kasc} or of class \code{asc}}
}
\value{
  Returns an object of class \code{kasc}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{  \code{\link{as.kasc}} for additional information on
  objects of class \code{kasc}, \code{\link{as.area}} for further
  information on the class \code{area} }
\examples{
data(puechabon)
kasc <- puechabon$kasc
locs <-  puechabon$locs

## Computes the home range of the animals
cp <- mcp(locs[,4:5], locs[,1])
area.plot(cp)

## Converts the home range to raster
cprast <- hr.rast(cp, kasc)
image(cprast)
}
\keyword{spatial}

\eof
\name{image.asc}
\alias{image.asc}
\alias{persp.asc}
\alias{contour.asc}
\alias{plot.asc}
\title{Displays a Color Image of an Object of Class 'asc' }
\description{
  These functions display a raster matrix of class \code{asc}.
}
\usage{
image.asc(x, clfac = NULL, col = gray((240:1)/256), \dots)
contour.asc(x, \dots)
persp.asc(x, \dots)
plot.asc(x, \dots)
}
\arguments{
  \item{x}{an object of class \code{asc}}
  \item{clfac}{for maps of type \code{"factor"}, a character vector giving
    the names of colors for each level of the factor (see
    \code{help(colasc)})}
  \item{col}{for maps of type \code{"numeric"}, the colors to be used
    (see \code{help(par)})} 
  \item{\dots}{additional arguments to be passed to the generic
    function \code{image}, \code{persp}, \code{contour}, and
    \code{filled.contour} (but see below)}
}

\section{Note}{
The function \code{plot.asc} uses the function
\code{filled.contour}. The output produced by \code{filled.contour} is
actually a combination of two plots; one is the filled contour and one
is the legend.  Two separate coordinate systems are set up for these
two plots, but they are only used internally - once the function has
returned these coordinate systems are lost.  If you want to annotate
the main contour plot, for example to add points, you can specify
graphics commands in the \code{plot.axes} argument of the function
\code{filled.contour} (this argument is to be passed to the function
\code{plot.asc}). 
An example is given below.
}

\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{image}},  \code{\link{contour}},
  \code{\link{persp}}, \code{\link{filled.contour}},
  \code{\link{import.asc}}
}

\examples{

data(puechabon)

# Case of a continuous variable: the elevation
my.map <- getkasc(puechabon$kasc, "Elevation")
image(my.map, main = "Elevation in Puechabon")
contour(my.map, add = TRUE)

# use of the function plot.asc: adding points on the map
plot(my.map, plot.axes = {points(puechabon$locs[,c("X","Y")])},
     main = "Elevation")

# Case of a factor: the aspect
asp <- getkasc(puechabon$kasc, "Aspect")
cl <- colasc(asp, NorthEast = "blue", SouthEast = "red", 
             SouthWest = "orange", NorthWest = "green")

## graphical display
image(asp, clfac = cl, main = "Aspect", xlab = "Lambert X",
      ylab = "Lambert Y") 
legend(706500, 3162000, legend = levels(asp), fill = cl,
       cex = 0.7)


opar<-par(mar = c(0,0,3,0), bg = "slategray")
persp(my.map, scale = FALSE, box = FALSE, border = NA, shade = 0.75, 
      col = "darkolivegreen3", expand = 2, theta = -60, phi = 30, 
      main = "The topography of Puechabon")
par(opar)


}
\keyword{hplot}

\eof
\name{image.sahrlocs}
\alias{image.sahrlocs}
\title{Graphical Display of the Habitat Composition of
  the Home Ranges of Animals Monitored Using Radio-Tracking }
\description{
  \code{image.sahrlocs} allows a gray-level display of the composition
  of home ranges (different colors are used for factors).
  For a given variable, the minimum gray level (default is
  \code{"white"}) and the maximum gray level (default is \code{"black"})
  represents respectively the minimum and the maximum of the variable
  \emph{***on the study area***}.
  
}
\usage{
image.sahrlocs(x, ani = names(x$hr), var = names(x$sa),
               mar = c(0, 0, 0, 0), axes = FALSE, dfidxy = NULL, colpts =
               "black", pch = 21, bg = "white", inv = FALSE, cexpts = 0.6, 
               csub = 2, possub = c("bottomleft", "bottomright", "topleft",
               "topright"), \dots)
}
\arguments{
  \item{x}{an object of class \code{sahrlocs}}
  \item{ani}{a character vector giving the names of the
    variables of the \code{"hr"} component (the animals) for which a
    display is wanted}
  \item{var}{a character vector giving the names of the
    variables of the \code{"sa"} component (the habitat variables) for
    which a display is wanted} 
  \item{mar}{the graphical parameter \code{mar} (see
    \code{\link{par}})}
  \item{axes}{logical.  Whether the axes should
    be plotted}
  \item{csub}{the character size for the legend, used with
    \code{par("cex")*csub}}
  \item{possub}{a character string indicating the sub-title position
    (\code{"topleft"}, \code{"topright"}, \code{"bottomleft"},
    \code{"bottomright"})} 
  \item{dfidxy}{an optional data frame with three columns giving the
    identity and the coordinates of the relocations of each animal.  (if
    not \code{NULL}, the relocations of each animal are plotted in its
    home range, see Examples)}
  \item{colpts}{if \code{dfidxy} is not \code{NULL}, the color of the
    points to be used for the plot of the relocations}
  \item{pch}{if \code{dfidxy} is not \code{NULL}, the size of the points
    to be used for the plot of the relocations (see \code{\link{par}})}
  \item{bg}{if \code{dfidxy} is not \code{NULL}, the background color to
    be used for the plot of the relocations (see \code{\link{par}})}
  \item{inv}{by default, lower values of the mapped variables are
    brighter.  If \code{FALSE}, the lower values are darker}
  \item{cexpts}{if \code{dfidxy} is not \code{NULL}, the size of the points}
  \item{\dots}{additionnal parameters to be passed to the generic
    function \code{image}}
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.sahrlocs}} for additionnal information on
  objects of class \code{sahrlocs} }

\examples{
data(puechabon)
sahr <- puechabon$sahr
sahr

## Displays all the variables for a given animal
image(sahr, ani = "Chou")

## Displays all the animals for a given variable
image(sahr, var = "Elevation")

## Load and displays the relocations of the animals
locs <-  puechabon$locs[,c(1,4:5)]
image(sahr, var = "Elevation", dfidxy = locs, pch = 21)
}
\keyword{spatial}
\keyword{multivariate}

\eof
\name{import.asc}
\alias{import.asc}
\alias{export.asc}
\alias{as.asc}
\alias{asc}
\alias{print.asc}
\title{ Arcview ASCII Raster File Importation And Exportation }
\description{
  \code{import.asc} imports Arcview ASCII raster file
  created with the Arcview command \code{"File -> Export data
    source"}.\cr
    Conversely,  \code{export.asc} allows to export an \code{asc}
    object toward Arcview.\cr
    ASCII raster files may also be created using the free program landserf
    (\url{http://www.soi.city.ac.uk/~jwo/landserf/}).
}
\usage{
import.asc(file, type = c("numeric", "factor"), lev = NULL,
           levnb = 1, labnb = 3)
export.asc(x, file)
as.asc(x, xll = 1, yll = 1, cellsize = 1, type = c("numeric", "factor"),
       lev = levels(factor(x)))
print.asc(x, \dots)
}

\arguments{
  \item{file}{a character string. The name of an Arcview ASCII Raster file}
  \item{type}{a character string. Either \code{"numeric"} or \code{"factor"}}
  \item{lev}{if \code{type = "factor"}, either a vector giving the
    labels of the factor levels, or the name of a file giving the
    correspondence table of the map (see details)}
  \item{levnb}{if \code{lev} is the name of a file containing a
    correspondence table exported from Arcview, the column number in
    this table where the factor levels are stored (i.e. the numbers indicating
    the levels of the factor)}
  \item{labnb}{if \code{lev} is the name of a file containing a
    correspondence table exported from Arcview, the column number in
    this table where the factor labels are stored (i.e. the character
    strings indicating the labels associated with each level of the factor)}
  \item{x}{an object of class \code{asc}.  For the function \code{as.asc}, a
    matrix}
  \item{xll}{the x coordinate of the center of the lower left pixel of the map}
  \item{yll}{the y coordinate of the center of the lower left pixel of the map}
  \item{cellsize}{the size of a pixel on the studied map}
  \item{\dots}{additionnal arguments to be passed to the function
    \code{print}}
}
\details{
The raster maps may be of type \code{"numeric"} (e.g. elevation on an area) or
\code{"factor"} (e.g. the type of vegetation
on an area).  If the map is of type \code{factor}, the levels should be
indicated.  The \code{".asc"} files store the values of the mapped variable 
with numeric values.  Each level of the factor is coded on the map by a
number.  The argument \code{lev} of \code{import.asc} or \code{as.asc}
gives the labels corresponding to each
number. Alternatively, these levels may be specified using a
correspondence table exported from Arcview (with this software, command
\code{"Theme -> table"}, then \code{"File -> Export"},
and finally export in delimited text format). An example of such file is
provided in the directory "ascfiles" of the package, see the examples below.
\code{export.asc} allows only exportation of numeric maps.
}
\value{
  Returns a raster matrix of the class \code{asc}, with the following
  attributes : 
  \item{xll}{the x coordinate of the center of the lower left pixel of
    the map}
  \item{yll}{the y coordinate of the center of the lower left pixel of
    the map}
  \item{cellsize}{the size of a pixel on the studied map}
  \item{type}{either \code{"numeric"} or \code{"factor"}.}
  \item{levels}{if \code{type = "factor"}, the levels of the factor.}
}
\references{Arcview: \url{http://www.esri.com}\cr
Landserf: \url{http://www.soi.city.ac.uk/~jwo/landserf/}
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{image.asc}} }

\examples{
\dontrun{
## Importation of asc files: numeric
## Path of the file to be imported
(file1 <-  paste(system.file(package = "adehabitat"),
               "ascfiles/Elevation.asc", sep = "/"))

el <- import.asc(file1)
image(el)
el


## Importation of asc files: factor
(file2 <- paste(system.file(package = "adehabitat"),
              "ascfiles/Aspect.asc", sep = "/"))
(levelfile <- paste(system.file(package = "adehabitat"),
              "ascfiles/Aspect.txt", sep = "/"))
asp <- import.asc(file2, lev = levelfile, type = "factor")
image(asp)
asp


## map of white noise
wafwaf <- matrix(rnorm(10000), 100, 100)
wafwaf <- as.asc(wafwaf)
image(wafwaf)

## exportation of a map
export.asc(wafwaf, "foo.asc")

## remove the created file:
file.remove("foo.asc")
}
}
\keyword{file}

\eof
\name{join.asc}
\alias{join.asc}
\alias{join.kasc}
\title{Finds the Value of Mapped Variables at some Specified Locations
  (Spatial Join)}
\description{
  \code{join.asc} finds the value of a mapped variable at some specified
  locations.\cr
  \code{join.kasc} is the same function as \code{join.asc}, 
  with several maps.
}
\usage{
 join.asc(pts, x) 
 join.kasc(pts, w) 
}

\arguments{
  \item{x}{an object of class \code{asc}}
  \item{w}{an object of class \code{kasc}}
  \item{pts}{the x and y coordinates of points to be placed on the map.}
}


\value{
  \code{join.asc} returns a vector with length equals to the number of
  points in \code{pts}.\cr
  \code{join.kasc} returns a data frame with a number of columns equals 
  to the number of variables in the object of class \code{kasc}, and
  with each row corresponding to the rows of \code{pts}.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{as.kasc}} and \code{\link{import.asc}}}

\examples{
data(puechabon)
x <- puechabon$kasc

## for each relocation, finds the values of the variables in x
toto <- join.kasc(pts = cbind(puechabon$locs$X, puechabon$locs$Y), x)
toto[1:4,]
}
\keyword{programming}
\keyword{hplot}

\eof
\name{kasc2df}
\alias{kasc2df}
\alias{df2kasc}
\title{Conversion of Objects of Class kasc}
\description{
  An object of class \code{kasc} stores several maps in a data frame
  (one column per variable, and one row per pixel of the raster map).
  However, the features mapped are rarely rectangle-shaped, whereas the
  map are inevitably rectangles.  Therefore, a lot of pixels of the maps
  do not contain data.  The pixels of the map that do not contain data
  are \code{NA} in this data frame.  \code{kasc2df} will "clean" the
  object of class \code{kasc} from these NAs, and will return a data
  frame containing only mapped values that can be used in subsequent
  analysis. \cr
  After these analyses, \code{df2kasc} may be used to convert the
  modified data frame to an object of 
  class \code{kasc} for mapping (e.g. for maps of factorial axes,
  using \code{dudi} analyses, see \code{help(dudi)}).
}
\usage{
kasc2df(x, var = names(x))
df2kasc(df, index, x)
}

\arguments{
  \item{x}{an object of class \code{kasc} in \code{kasc2df}\cr
  an object of class \code{kasc} or \code{mapattr} in \code{df2kasc}}
  \item{var}{a character vector.  The names of the variables in the
    \code{kasc} that are to be kept in the output}
  \item{df}{a data frame resulting of a computation of the component
    \code{tab} of the list previously returned by the  \code{kasc2df}
    (see section \code{Value} below).  This computation may be any form
    of analysis (Principal component analysis, modelling techniques,
    etc.) }
  \item{index}{an integer vector giving the position of the rows of
    \code{df} in the returned \code{kasc} (such an index can be computed
    using \code{kasc2df})}
}
\value{
  \code{kasc2df} returns a list with the following components:
  \item{tab}{a data frame without NAs, with a number of variables equals
    to \code{length(var)}.}
  \item{index}{a vector of indices of the rows of the \code{kasc} kept
    for the analyses (that is, not \code{NA}).}
  \code{df2kasc} returns an object of class \code{kasc}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{as.kasc}} for additional information on
  objects of class \code{kasc}.
}

\examples{
data(puechabon)
kasc <- puechabon$kasc

# Display the kasc object
image(kasc)

# Preparation for Principal component analysis
x <- kasc2df(kasc)
x$tab <- x$tab[, (names(x$tab) != "Aspect")]

# Principal component analysis
ana <- dudi.pca(x$tab, scannf = FALSE)

s.arrow(ana$co)
s.label(ana$li, clab = 0)


## Map of the scores of the rows
scores <- df2kasc(ana$li, x$index, kasc)
image(scores)
}
\keyword{multivariate}
\keyword{NA}

\eof
\name{kernelUD}
\alias{kernelUD}
\alias{print.khr}
\alias{image.khr}
\alias{plotLSCV}
\alias{getvolumeUD}
\alias{kernel.area}
\alias{getverticeshr}
\title{Estimation of Kernel Home-Range}
\description{
  \code{kernelUD} is used to estimate the utilization distribution (UD)
  of animals monitored by radio-tracking.\cr
  \code{getvolumeUD} and \code{kernel.area} provide utilities
  for home-range size estimation.\cr
  \code{getverticeshr} stores the
  home range contour as objects of class \code{area} in a list, with one
  component per animal.
}
\usage{
kernelUD(xy, id = NULL, h = "href", grid = 40, same4all = FALSE,
         hlim = c(0.1, 1.5))
print.khr(x, \dots)
image.khr(x, axes = FALSE, mar = c(0,0,2,0),
          addcontour = TRUE, addpoints = TRUE, \dots)
plotLSCV(x)
getvolumeUD(x)
kernel.area(xy, id, h = "href", grid=40,
            same4all = FALSE, hlim = c(0.1,1.5),
            levels = seq(20,95, by = 5),
            unin = c("m", "km"),
            unout = c("ha", "km2", "m2"))
getverticeshr(x, lev = 95)
}

\arguments{
  \item{xy}{a data frame with two columns (x and y coordinates of the
    animal relocations)}
  \item{id}{an optional factor giving the animals identity associated to
    \code{xy}}
  \item{h}{a character string or a number.  If \code{h} is set to
    \code{"href"}, the ad hoc method is used for the smoothing parameter
    (see details).  If \code{h} is set to 
    \code{"LSCV"}, the least-square cross validation method is used.
    Alternatively, \code{h} may be set to any given numeric value}
  \item{grid}{a number giving the size of the grid on
    which the UD should be estimated.  Alternatively, this parameter may
    be an object of class \code{asc} (see examples)}
  \item{same4all}{logical. If \code{TRUE}, the same grid
    is used for all animals.  If \code{FALSE}, one grid per
    animal is used}
  \item{hlim}{a numeric vector of length two.  If \code{h = "LSCV"},
    the function minimizes the cross-validation criterion for values of
    h ranging from \code{hlim[1]*href} to \code{hlim[2]*href}, where
    \code{href} is the smoothing parameter computed with the ad hoc
    method (see below)}
  \item{x}{an object of class \code{khr} returned by \code{kernelUD}}
  \item{axes}{logical.  Whether the axes are to be plotted}
  \item{mar}{the margin parameter (see \code{help(par)})}
  \item{addcontour}{logical. if \code{TRUE}, contours are drawn on the
    graphics}
  \item{addpoints}{logical. if \code{TRUE}, the animal relocations are
    drawn on the graphics}
  \item{levels}{a vector of percentage levels for home-range size
    estimation}
  \item{unin}{the units of the relocations coordinates.  Either \code{"m"} for
    meters (default) or \code{"km"} for kilometers}
  \item{unout}{the units of the output areas.  Either \code{"m2"} for
    square meters, \code{"km2"} for square kilometers or \code{"ha"} for
    hectares (default)}
  \item{lev}{the percentage level for home range contour estimation.}
  \item{\dots}{additionnal parameters to be passed to the generic
    functions \code{print} and \code{image}}
}
\details{
  The Utilization Distribution (UD) is the bivariate function giving the
  probability density that an animal is found at a point according to
  its geographical coordinates.  Using this model, one can define 
  the home range as the minimum area in which an animal has some
  specified probability of being located. The
  functions used here correspond to the approach described in Worton
  (1995). \cr

  The kernel method has been recommended by many authors for the
  estimation of the utilization distribution (e.g. Worton, 1989, 1995).
  The default method for the estimation of the
  smoothing parameter is the \emph{ad hoc} method, i.e.
  \deqn{h = \sigma n^{- \frac{1}{6}}}{h = Sigma*n^(-1/6)}
  where \deqn{\sigma = 0.5 (\sigma(x)+\sigma(y))}{Sigma =
    0.5*(sd(x)+sd(y))} which supposes that the UD is
  bivariate normal.  Alternatively, the smoothing parameter h may be
  computed by Least Square Cross Validation (LSCV).  The estimated value
  then minimizes the Mean Integrated Square Error (MISE), i.e. the
  difference in volume between the true UD and the estimated UD.  Note
  that the cross-validation criterion cannot be minimized in some
  cases.  According to Seaman and Powell (1998) \emph{"This is a difficult
  problem that has not been worked out by statistical
  theoreticians, so no definitive response is available at this
  time"} (see Seaman and Powell, 1998 for further details and tricky
  solutions).  \code{plotLSCV} allows to have a diagnostic of the
  success of minimization of the cross validation criterion (i.e. to
  know whether the minimum of the CV criterion occurs within the scanned
  range).  Finally, the UD is then estimated over a grid.\cr

  The function \code{getvolumehr} modifies the UD component of the
  object passed as argument, so
  that the contour of the UD displayed by the functions \code{contour}
  and \code{image.khr} corresponds to the different percentage levels of
  home-range estimation (see examples).  In addition, this function is
  used in the function \code{kernel.area}, to compute the home-range
  size.  Note, that the function \code{plot.hrsize} (see the help page
  of this function) can be used to display the home-range size estimated
  at various levels.
}
\value{
  The class \code{khr} is a class grouping two sub-classes,
  \code{khrud} and \code{khrudvol}:
  \code{kernelUD} returns a list of the class \code{khrud}.  This list
  has one component per animal (named as the levels of argument
  \code{id}). Each component is itself a list, with the following
  sub-components: 
  \item{UD}{an object of class \code{asc}, with the values of density
    probability in each cell of the grid}
  \item{h}{if \code{LSCV} is not used, the value of the smoothing
    parameter.  if
    \code{LSCV} is used, a list with three components: \describe{
      \item{\code{CV}}{the results of the cross-validation procedure.
	The first 
	column contains the sequence of values tested for the smoothing 
	parameter, and the second column contains the value of the
	cross-validation criterion.}
      \item{\code{convergence}}{TRUE if the LSCV succeeds (i.e. if the
	optimum smoothing parameter have been found by the procedure),
	FALSE otherwise.}
      \item{\code{h}}{the value of the smoothing parameter used in UD
	estimation.}
    }
  }
  \item{locs}{The relocations used in the estimation procedure.}
  \item{hmeth}{The argument \code{h} of the function kernelUD}

  \code{getvolumeUD} returns a list of class \code{khrvol},
  with the same components as lists of class \code{khrud}.  \cr

  \code{kernel.area} returns a data frame of subclass \code{"hrsize"},
  with one column per animal and one row per level of
  estimation of the home range.\cr

  \code{getverticeshr} returns a
  list of objects of class \code{area}.
}
\references{

  Silverman, B.W. (1986)
  \emph{Density estimation for statistics and data
    analysis}. London: Chapman \& Hall.
  
  Worton, B.J. (1989) Kernel methods for estimating the utilization
  dirstibution in home-range studies. \code{Ecology}, \bold{70}, 164--168.

  Worton, B.J. (1995) Using Monte Carlo simulation to evaluate
  kernel-based home range estimators. \code{Journal of Wildlife Management},
  \bold{59},794--800.

  Seaman, D.E. and Powell, R.A. (1998) \emph{Kernel home range estimation
    program (kernelhr)}. Documentation of the
  program. \url{ftp://ftp.im.nbs.gov/pub/software/CSE/wsb2695/KERNELHR.ZIP}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{import.asc}} for additionnal informations on
  objects of class \code{asc},  \code{\link{mcp}} for estimation of home
  ranges using the minimum convex polygon, and for help on the function
  \code{plot.hrsize}. }

\examples{

data(puechabon)
loc <- puechabon$locs[, c("X", "Y")]
id <- puechabon$locs[, "Name"]

## Estimation of UD for the four animals
ud <- kernelUD(loc, id)
ud

image(ud) ## Note that the contours
          ## corresponds to values of probability density
udvol <- getvolumeUD(ud)
image(udvol)
## Here, the contour corresponds to the
## home ranges estimated at different probability
## levels (i.e. the contour 90 corresponds to the 90 percent
## kernel home-range)
## udvol describes, for each cell of the grid,
## the smaller home-range to which it belongs 

## Calculation of the 95 percent home range
ver <- getverticeshr(ud, 95)
elev <- getkasc(puechabon$kasc, "Elevation") # Map of the area
image(elev)
for (i in 1:length(ver))
  lapply(split(ver[[i]][,2:3],ver[[i]][,1]),
           function(x) polygon(x, col = i+1))
legend(696500, 3166000, legend = names(ver), fill = 2:5)


## Example of estimation using LSCV
udbis <- kernelUD(loc, id, h = "LSCV")
image(udbis)

## Compare the estimation with ad hoc and LSCV method
## for the smoothing parameter
(cuicui1 <- kernel.area(loc, id)) ## ad hoc
plot(cuicui1)
(cuicui2 <- kernel.area(loc, id, h = "LSCV")) ## LSCV
plot(cuicui2)

## Diagnostic of the cross-validation
plotLSCV(udbis)


## Use of the same4all argument: the same grid
## is used for all animals
udbis <- kernelUD(loc, id, same4all = TRUE)
image(udbis)

## And finally, estimation of the UD on a map
## (e.g. for subsequent analyses on habitat selection)
elev <- getkasc(puechabon$kasc, "Elevation")
opar <- par(mfrow = c(2, 2), mar = c(0, 0, 2, 0))
cont <- getcontour(elev)

for (i in 1:length(udbis)) {
   image(elev, main = names(udbis)[i], axes = FALSE)
   points(udbis[[i]]$locs, pch = 21, bg = "white", col = "black")
}


## Measures the UD in each pixel of the map
udbis <- kernelUD(loc, id, grid = elev)
opar <- par(mfrow = c(2, 2), mar = c(0, 0, 2, 0))
for (i in 1:length(udbis)) {
  image(udbis[[i]]$UD, main = names(udbis)[i], axes = FALSE)
  box()
  polygon(cont[, 2:3])
}
par(opar)


}
\keyword{spatial}


\eof
\name{kselect}
\alias{kselect}
\alias{print.kselect}
\alias{hist.kselect}
\alias{kplot.kselect}
\alias{plot.kselect}
\title{ K-Select Analysis: a Method to Analyse the Habitat Selection by
  Animals  }
\description{
Performs a multivariate analysis of ecological data (K-select analysis).
}
\usage{
kselect(dudi, factor, weight, scannf = TRUE, nf = 2, ewa = FALSE)
print.kselect(x, \dots)
kplot.kselect(object, xax = 1, yax = 2, csub = 2, possub = c("topleft",
              "bottomleft", "bottomright", "topright"),
              addval = TRUE, cpoint = 1, csize = 1, clegend = 2, \dots)
hist.kselect(x, xax = 1, mar = c(0, 0, 0, 0), ampl = 1, 
             col.out = gray(0.75), col.in = gray(0.75), ncell = TRUE,
             denout = NULL, denin = NULL, lwdout = 1, lwdin = 1,
             maxy = 1, csub = 2, possub =
             c("bottomleft", "topleft", "bottomright", "topright"),
             ncla = 15, \dots) 
plot.kselect(x, xax = 1, yax = 2, \dots)
}
\arguments{
  \item{dudi}{an object of class \code{dudi}}
  \item{factor}{a factor with the same length as \code{nrow(dudi$tab)}}
  \item{weight}{a numeric vector of integer values giving the weight
    associated to the rows of \code{dudi$tab}.}
  \item{scannf}{logical. Whether the eigenvalues bar plot
    should be displayed}
  \item{nf}{if \code{scannf = FALSE}, an integer indicating the number
    of kept axes}
  \item{ewa}{logical. If \code{TRUE}, uniform weights are given
    to all animals in the analysis. If \code{FALSE}, animal weights are
    given by the proportion of relocations of each animal (i.e. an
    animal with 10 relocations has a weight 10 times lower than an
    animal with 100 relocations)}
  \item{x}{an object of class \code{kselect}}
  \item{object}{an object of class \code{kselect}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{addval}{logical.  If \code{TRUE}, the frequency of the
    relocations per animal is displayed (see examples)}
  \item{cpoint}{the size of the points (if 0, the points where no
    relocations are found are not displayed)}
  \item{mar}{the margin parameter (see \code{help(par)}).}
  \item{ampl}{the amplification factor (i.e. \code{ylim = c(-1 , 1) /
      ampl})} 
  \item{col.out}{character string.  The color of the upper histogram}
  \item{col.in}{character string.  The color of the lower histogram}
  \item{ncell}{logical. If \code{TRUE}, the histogram shows the
    distribution of the cells of 
    the raster map where at least one relocation is found. If
    \code{FALSE}, the histogram shows the distribution of the
    relocations}
  \item{denout}{the density of shading lines for the
    upper histogram, in lines per inch (see
    \code{help(hist)} for further informations)}
  \item{denin}{the density of shading lines for the
    lower histogram, in lines per inch}
  \item{lwdout}{the line width for the upper histogram}
  \item{lwdin}{the line width for the lower histogram}
  \item{maxy}{the maximum Y coordinate (since the histogram draws
    frequencies, default value of \code{maxy} is 1)}
  \item{csub}{the character size for the legend, used with
    \code{par("cex")*csub}}
  \item{csize}{the size coefficient for the points}
  \item{clegend}{the character size for the legend used by
    \code{par("cex")*clegend}}
  \item{possub}{a character string indicating the sub-title position
    \code{("topleft", "topright", "bottomleft", "bottomright")}}
  \item{ncla}{the number of classes of the histograms}
  \item{\dots}{additional arguments to be passed to the generic function
  \code{hist}, \code{print} or, in the case of \code{plot.kselect},
  \code{s.distri}}
}
\value{
  \code{kselect} returns a list of the class \code{kselect} and
\code{dudi} (see \code{\link[ade4]{dudi}}). 
}
\references{
  Calenge, C., Dufour, A.B. and Maillard,
  D. (\emph{submitted}). K-select analysis, a new method to analyse
  habitat selection in radio-tracking studies.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{sahrlocs2kselect}} for
  conversion of objects class \code{sahrlocs} to objects suitable for a
  K-select analysis, \code{\link[ade4]{s.distri}}, and
  \code{\link[ade4]{dudi}} for class \code{dudi}.}

\examples{

\dontrun{
## Loads the data
data(puechabon)
sahr <- puechabon$sahr

## prepares the data for the kselect analysis
x <- sahrlocs2kselect(sahr)
tab <- x$tab

## Example of analysis with two variables: the slope and the elevation.
## Have a look at the use and availability of the two variables
## for the 4 animals
tab <- tab[,((names(tab) == "Slope")|(names(tab) == "Elevation"))]
tab <- scale(tab)
tmp <- split.data.frame(tab, x$factor)
wg <- split(x$weight, x$factor)
opar <- par(mfrow = n2mfrow(nlevels(x$factor)))
for (i in names(tmp))
  s.distri(scale(tmp[[i]]), wg[[i]])
par(opar)

## We call a new graphic window
x11()
## A K-select analysis
acp <- dudi.pca(tab, scannf = FALSE, nf = 2)
kn <- kselect(acp, x$factor, x$weight,
 scannf = FALSE, nf = 2)

# use of the generic function scatter
scatter(kn)

# Displays the first factorial plane
kplot(kn)
kplot(kn, cellipse = 0, cpoint = 0)
kplot(kn, addval = FALSE, cstar = 0)

# this factorial plane can be compared with
# the other graph to see the rotation proposed by
# the analysis
graphics.off()

# Displays the first factorial axis
hist(kn)

# Displays the second factorial axis
hist(kn, xax = 2)

# Summary of the analysis
plot(kn)
}
}
\keyword{multivariate}
\keyword{hplot}

\eof
\name{labcon}
\alias{labcon}
\title{Labelling Connected Features }
\description{
  This function attributes unique labels to pixels belonging to connected
  features on a map of class \code{asc}.
}
\usage{
labcon(x)
}
\arguments{
  \item{x}{an object of class \code{asc}}
}
\value{
  Returns a matrix of class \code{asc}, of type \code{"factor"}, with a
  number of levels equals to the number of connected components
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{\code{\link{as.asc}}}

\examples{
  data(puechabon)
  hr <- getsahrlocs(puechabon$sahr, "hr")
  u <- getkasc(hr, "Jean")
  image(u)

  ## numbering of the connected components
  p <- labcon(u)
  nlevels(p)
  image(p)

  ##  stores the first component
  c1 <- p
  c1[c1 != 1] <- NA
  image(c1)

  ##  stores the second component
  c2 <- p
  c2[c2 != 2] <- NA
  image(c2)
}
\keyword{spatial}


\eof
\name{lowres}
\alias{lowres}
\alias{lowres.asc}
\alias{lowres.kasc}
\title{Reducing the Resolution of a Map}
\description{
  \code{lowres} is a generic function, having methods for the classes
  \code{asc} and \code{kasc}. It is used to reduce the resolution of
  the maps.
}
\usage{
lowres(x, np = 2, ...)
}
\arguments{
  \item{x}{an object of class \code{asc} or \code{kasc}}
  \item{np}{a number giving the number of pixels to merge together
    (see below)}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
  The function merges together squares of \code{np * np} pixels.  For
  maps of type \code{"numeric"} (see
  \code{help(as.asc)}), the function averages the value of the variable.
  For maps of type \code{"factor"}, the function gives the most
  frequent level in the square of \code{np * np} pixels.  When several
  levels are equally represented in the square of \code{np * np} pixels,
  the function randomly samples one of these levels.
}
\value{
  Returns an object of class \code{asc} or \code{kasc}.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{\code{\link{as.asc}}, \code{\link{as.kasc}} }
\examples{
data(puechabon)
kasc <- puechabon$kasc

## The initial image
image(kasc)

## The transformed image
m <- lowres(kasc, np = 4)
image(m)

}
\keyword{spatial}

\eof
\name{lynxjura}
\alias{lynxjura}
\docType{data}
\title{Monitoring of Lynx}
\description{
  This data set stores the results of the monitoring of lynx in the
  French Jura between 1980 and 1999.  These data have been collected by
  the Lynx Network of the french wildlife management office (Office
  national de la chasse et de la faune sauvage).
}
\usage{data(lynxjura)}
\format{
The list \code{lynxjura} has two components: \describe{
\item{\code{map}}{an object of class \code{kasc} (see
  \code{help(as.kasc)}) that describes several variables on the study
  area:  \code{forets} is the density of forests, \code{hydro} is the
  density of rivers, \code{routes} is the density of roads and
  \code{artif} is the distance from urbanized areas.}
\item{\code{locs}}{a data frame containing the locations of presence
  indices of the lynx.  \code{X} and \code{Y} are the x and y
  coordinates, \code{Date} is the date of the collection of the 
  indice and \code{Type} represents the type of data (\code{C}: alive
  lynx captured, \code{D}: attacks on livestock, \code{E}: prints or
  tracks, \code{F}: feces, \code{J}: hairs, \code{L}: corpse of lynx,
  \code{O}: sightings and \code{P}: attacks on wild prey).}
}
}
\source{
Vandel, J.M. (2001) \textit{Rpartition du Lynx (Lynx lynx) en France (Massif
Alpin, Jurassien et Vosgien). Mthodologie d'tude et statut
actuel}. Ecole Pratique des Haute Etudes de Montpellier II:
Dissertation.
}
\keyword{datasets}

\eof
\name{mahasuhab}
\alias{mahasuhab}
\title{Habitat Suitability Mapping with Mahalanobis Distances.}
\description{
This function computes the habitat suitability map of an area
for a species, given a set of locations of the species occurences (Clark
et al. 1993).  This function is
to be used in habitat selection studies, when animals are not
identified.
}
\usage{
mahasuhab(kasc, pts, type = c("distance", "probability"))
}
\arguments{
  \item{kasc}{a raster map of class \code{kasc}}
  \item{pts}{a data frame with two columns, giving the coordinates
    of the species locations}
  \item{type}{a character string. Whether the raw \code{"distance"} should be
    returned, or rather the \code{"probability"} (see details). }
}
\details{
  Let assume that a set of locations of the species on an area is available
  (gathered on transects, or during the monitoring of the population,
  etc.).  If we assume that the probability of detecting an individual
  is independent from the habitat variables, then we can consider that
  the habitat found at these sites reflects the habitat use by the animals.\cr
  
  The Mahalanobis distance method has become more and more popular
  during the past few years to derive habitat suitability maps.  The
  niche of a species is defined as the probability density function of
  presence of a species in the multidimensionnal space defined by the
  habitat variables.  If this function can be assumed to
  be multivariate normal, then the mean vector of this distribution
  corresponds to the optimum for the species.\cr

  The function \code{mahasuhab} first computes this mean vector as well
  as the variance-covariance matrix of the niche density function, based
  on the value of habitat variables in the sample of locations.
  Then, the Mahalanobis distance from this optimum is computed for each pixel
  of the map.  Thus, the smaller this
  distance is for a given pixel, and the better is the habitat in this
  pixel.

  Assuming multivariate normality, Mahalanobis distances are
  approximately distributed as Chi-square with n-1 degrees of freedom,
  where n equals the number of habitat characteristics.  If the
  argument \code{type = "probability"}, maps of these p-values are
  returned by the function. As such these are the probabilities of a
  larger Mahalanobis distance than that observed when x is sampled from
  a population whose mean is ideal.
}
\value{
  Returns a raster map of class \code{asc}.
}
\references{
Clark, J.D., Dunn, J.E. and Smith, K.G. (1993) A multivariate model of
female black bear habitat use for a geographic information
system. \emph{Journal of Wildlife Management}, \bold{57}, 519--526.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\note{
  The computation of the Mahalanobis distances inverts the
  variance-covariance matrix of the niche density function (see
  \code{?mahalanobis}).
  It is therefore important that the habitat variables considered
  are not too correlated among each other.  When the habitat variables
  are too correlated, the variance-covariance matrix is singular and
  cannot be inverted. \cr

  Note also that it is recommended to scale the variables before the
  computation, so that they all have the same variance, and therefore
  the same weight in the analysis (see examples below).
}
\seealso{ \code{\link{as.asc}} for further information on objects of
  class \code{asc}, \code{\link{as.kasc}} for additional information on
  objects of class \code{kasc}, \code{\link{domain}} for another method
  of habitat suitability mapping, and \code{\link[stats]{mahalanobis}} for
  information on the computation of mahalanobis distances. }
\examples{
## loads the data
data(lynxjura)
ka <- lynxjura$map
lo <- lynxjura$locs[,1:2]

## We first scale the maps
df <- kasc2df(ka)
pc <- dudi.pca(df$tab, scannf=FALSE)
tab <- pc$tab
ka <- df2kasc(tab, df$index, ka)

## habitat suitability mapping
hsm <- mahasuhab(ka, lo, type = "probability")
plot(hsm, main = "Habitat suitability map for the Lynx",
     plot.axes = { points(lo, pch = 16, cex=0.5)})
}
\keyword{spatial}
\keyword{multivariate}

\eof
\name{managNAkasc}
\alias{managNAkasc}
\alias{managNAkasc}

\title{"Cleaning" Objects of Class 'kasc'}
\description{
  An object of class \code{kasc} stores several maps in a data frame
  (one column per variable, and one row per pixel of the raster map).
  However, the features mapped are rarely rectangle-shaped, whereas the
  map are inevitably rectangles.  Therefore, a lot of pixels of the maps
  do not contain data.  The pixels of the map that do not contain data
  are \code{NA} in this data frame. \cr
  It often occurs that several variables are not mapped for exactly the
  same area (that is, some pixels are \code{NA} for some variables, and
  not for others). \code{managNAkasc} will set to \code{NA} all pixels
  that are not mapped for all variables.
}
\usage{
managNAkasc(x)
}

\arguments{
  \item{x}{an object of class \code{kasc}}
}
\value{
  Returns an object of class \code{kasc}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{as.kasc}} for additional information on
  objects of class \code{kasc}.
}
\keyword{multivariate}
\keyword{NA}

\eof
\name{mcp}
\alias{mcp}
\alias{plot.hrsize}
\alias{mcp.area}
\title{Estimation of the Home Range Using the Minimum Convex Polygon
  Estimator}
\description{
  \code{mcp} computes the home range of several
  animals using the minimum convex polygon estimator.\cr
  \code{mcp.area} is used for home-range size estimation.  This function
  requires the package \code{gpclib}.\cr
  \code{plot.hrsize} is used to display the home-range size estimated at
  various levels.
}
\usage{
mcp(xy, id, percent = 95)
mcp.area(xy, id, percent = seq(20,95, by=5)
         unin = c("m", "km"),
         unout = c("ha", "km2", "m2"))
plot.hrsize(x, \dots)
}
\arguments{
  \item{xy}{a data frame containing the coordinates of the relocation
    of the monitored animals}
  \item{id}{a factor giving the identity of the animal for each relocation}
  \item{percent}{100 minus the proportion of outliers to be excluded
    from the computation }
  \item{unin}{the units of the relocations coordinates.  Either
    \code{"m"} (default) for
    meters or \code{"km"} for kilometers}
  \item{unout}{the units of the output areas.  Either \code{"m2"} for
    square meters, \code{"km2"} for square kilometers or \code{"ha"} for
    hectares (default)}
  \item{x}{an objet of class \code{hrsize} returned by the function
    \code{mcp.area}, or \code{kernel.area} (see the help page of this
    function)}
  \item{\dots}{additionnal arguments to be passed to the function
    \code{plot}}
}
\details{
  This function computes the Minimum Convex Polygon estimation after the
  removal of \code{(100 minus percent)} percent of the relocations the
  farthest away from the barycenter of the home range (computed by the
  arithmetic mean of the coordinates of the relocations for each
  animal).\cr
}
\value{
  \code{mcp} returns an object of class \code{area}, with one polygon
  per level of the factor ID.\cr
  \code{mcp.area} returns a data frame of class \code{hrsize}, 
  with one column per animal and one row per level of
  estimation of the home range
}
\references{
  Mohr, C.O. (1947) Table of equivalent populations of north
  american small mammals. \emph{The American Midland Naturalist},
  \bold{37}, 223-249.}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{ \code{\link{chull}}, \code{\link[ade4]{area.plot}} to have a
  graphical display of the home ranges, \code{\link{as.area}} for
  additionnal information on the class \code{area}, and
  \code{\link{area2dxf}} for further exportation toward a GIS.
  \code{\link[ade4]{s.chull}} for another way to display MCP}
\examples{
data(puechabon)
locs <-  puechabon$locs

cp <- mcp(locs[,4:5], locs[,1])

## Plot the home ranges
opar <- par(mar = c(0,0,0,0))
area.plot(cp)

## ... And the relocations
points(locs[,4:5], pch = 16, col = as.numeric(locs[,1]))
par(opar)

## Computation of the home-range size:
if (require(gpclib)) {
  (cuicui1 <- mcp.area(locs[,4:5], locs[,1]))
  plot(cuicui1)
}

}

\keyword{hplot}

\eof
\name{mcp.rast}
\alias{mcp.rast}
\title{Converts a Polygon to Raster}
\description{
  \code{mcp.rast} converts a polygon map to a raster map of class
  \code{asc}.
}
\usage{
  mcp.rast(poly, w)
}
\arguments{
  \item{poly}{a data frame with 2 columns giving the coordinates
              of a polygon object}
  \item{w}{an object of class \code{kasc}, or of class \code{asc}}
}
\value{
Returns an object of class \code{asc}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{hr.rast}}}
\examples{
data(puechabon)
toto <- puechabon$kasc
loc <- puechabon$locs

## gets the coordinates of the relocations for the wild boar #1
wb1 <- loc[loc$Name == "Chou",]
wb1 <- cbind(wb1$X, wb1$Y)
nbpol <- chull(wb1)
xycoord <- wb1[nbpol,]

## rasterization of wb1
tutu <- mcp.rast(xycoord, toto)
image(tutu)

polygon(xycoord, lwd = 2)
}
\keyword{spatial}





\eof
\name{morphology}
\alias{morphology}
\title{Morphology: Erosion or Dilatation of Features on a Raster Map}
\description{
  \code{morphology} performs morphological operations on images
  of class \code{asc}.
}
\usage{
morphology(x, operation = c("erode", "dilate"), nt = 5)
}
\arguments{
  \item{x}{a matrix of class \code{asc}}
  \item{operation}{a character string indicating the operation to be
    processed: either \code{"erode"} or \code{"dilate"}}
  \item{nt}{the number of times that the operation should be processed}
}
\value{
Returns a matrix of class \code{asc}, containing 1 when the pixel belong
to one feature of the image and \code{NA} otherwise (see examples).  
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{\code{\link{as.asc}} for further information on objects of
  class \code{asc}} 
\examples{
data(puechabon)
a <- getkasc(puechabon$kasc,"Elevation")

## dilatation
toto1 <- morphology(a, operation = "dilate", nt = 1)
toto2 <- morphology(a, operation = "dilate", nt = 2)
toto3 <- morphology(a, operation = "dilate", nt = 3)
toto5 <- morphology(a, operation = "dilate", nt = 5)
image(toto5, col = "red")
image(toto3, add = TRUE, col = "orange")
image(toto2, add = TRUE, col = "yellow")
image(toto1, add = TRUE, col = "green")
image(a, add = TRUE)

## erosion
image(a, col = 1)
for (i in 1:19) {
  toto <- morphology(a, operation = "erode", nt = i)
  image(toto, add = TRUE, col = palette()[(i+1)\%\%8])
}


}
\keyword{spatial}


\eof
\name{niche.test}
\alias{niche.test}
\title{Monte-Carlo Test on Parameters of the Ecological Niche}
\description{
  \code{niche.test} tests for the significance of two parameters of the
  ecological niche of a species (marginality and tolerance), using
  Monte-Carlo methods.  This is a bivariate test.
}
\usage{
niche.test(kasc, points, nrep = 999, h, o.include = FALSE,
           colZ = "blue", colS = "orange", \dots) 
}
\arguments{
  \item{kasc}{a raster map of class \code{kasc}}
  \item{points}{a data frame with two columns, giving the coordinates of
    the species locations}
  \item{nrep}{the number of permutations}
  \item{h}{vector of bandwidths for x and y directions passed to
    \code{biv.test}, used in the function \code{kde2d} of the package
    \code{MASS}.  Defaults to normal reference bandwidth (see \code{?kde2d}).}
  \item{o.include}{logical, passed to \code{biv.test}.  If \code{TRUE},
    the origin is included in the plot}
  \item{colZ}{a color passed to \code{biv.test} for the color of the kernel
    density estimation of the randomized values}
  \item{colS}{a color passed to \code{biv.test} for the actual values of
    marginality and tolerance of the object of class \code{enfa}}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
  \code{niche.test} tests the significance of two parameters describing
  the ecological niche: the marginality
  (squared length of the vector linking the average available habitat
  conditions to the average used habitat conditions in the ecological
  space defined by the habitat variables), and the tolerance (inertia of
  the niche in the ecological space, i.e. the sum over all variables of
  the variance of used pixels). \cr
  
  At each step of the randomisation procedure, 
  the test randomly allocates the n points in the pixels of the map.
  The marginality and the tolerance are then recomputed on this
  randomised data set.\cr
  
  Actual values are compared to random values with the help of the
  function \code{biv.test}.
}
\value{
Returns a list containing the following
components: 
\item{dfxy}{a data frame with the randomized values of marginality
  (first column) and tolerance (second column).}
\item{obs}{the actual value of marginality and tolerance.}
}
\author{
  Mathieu Basille \email{basille@biomserv.univ-lyon1.fr}\cr
  Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}
}
\section{Warning}{
 \code{biv.test} uses the function \code{kde2d} of the package \code{MASS}.
}
\seealso{\code{\link{biv.test}} for more details on bivariate tests. }
\examples{
\dontrun{
data(lynxjura)

## We keep only "wild" indices.
tmp=lynxjura$loc[,4]!="D"
if (require(MASS))
   niche=niche.test(lynxjura$map,
                    lynxjura$locs[tmp, c("X", "Y")])
}
}
\keyword{multivariate}

\eof
\name{pheasant}
\docType{data}
\alias{pheasant}
\title{Radio-Tracking of Pheasants}
\description{
This data set describes the use and availability of 5 habitat types for
13 pheasants monitored using radio-tracking. 
}
\usage{data(pheasant)}
\format{
  This list has three components:
  \describe{
    \item{\code{studyarea}}{a data frame giving the proportion of each
      habitat type (columns) on the study area.  These habitat types are
      \code{Scrub}, \code{Broadleaf}, \code{Coniferous},
      \code{Grassland} and \code{Crop}.  These proportions are
      repeated by rows, for all animals (rows)}
    \item{\code{mcp}}{a data frame giving the proportion of
      each habitat type (columns) in the home range of each animal
      (rows)}
    \item{\code{locs}}{a data frame giving the proportion of relocations
      of each animal (rows) reported in 3 of the 5 habitat types
      (columns). Indeed, \code{Coniferous} and \code{Crops} were not
      used by most of the animals.}
    }
}
\source{
  Aebischer, N. J., Robertson, P. A. and Kenward, R. E. (1993)
  Compositional analysis of habitat use from animal radiotracking
  data. \emph{Ecology}, \bold{74}, 1313--1325.
}
\keyword{datasets}

\eof
\name{plot.sahrlocs}
\alias{plot.sahrlocs}
\alias{print.plotsahr}
\title{Exploratory Analysis of Habitat Selection}
\description{
  \code{plot.sahrlocs} applies the function \code{widesII} or
  \code{widesIII} for each  variable in the object of class
  \code{sahrlocs}, and the results are stored in a list.  Then, the
  function \code{plot.wi} is applied to each component of
  the list.  This allows to investigate habitat selection by animals at
  several scales for design II and III data.
}
\usage{
plot.sahrlocs(x, ani = names(x$hr), var = names(x$sa),
              type = c("hr.in.sa", "locs.in.hr", "locs.in.sa"),
              ncla = 4, ylog = FALSE, caxis = 0.7, clab = 0.7,
              errbar = c("SE", "CI"), alpha = 0.05, draw = TRUE, ...)
}
\arguments{
  \item{x}{an object of class \code{sahrlocs}}
  \item{ani}{a character vector.  This vector contains the names
    of the animals in \code{x} for which habitat selection should be
    displayed.  At least two animals are required}
  \item{var}{a character vector.  This vector contains the names
    of the variables in \code{x} for which habitat selection should be
    displayed}
  \item{type}{a character string. Type of habitat selection that should
    be investigated. 
    If \code{"hr.in.sa"}, the selection of the home-range within the study
    area is displayed.  If \code{"locs.in.sa"}, the selection of the
    relocations within the study area is displayed. If
    \code{"locs.in.hr"}, the selection of the relocations within the home
    range is displayed}
  \item{ncla}{numeric variables are converted to factors.  This
    parameter controls the number of classes of these factors}
  \item{ylog}{logical.  If \code{TRUE}, the selection ratios are plotted
    on a log scale}
  \item{caxis}{character size on axes to be passed to
    \code{par("cex.axis")}}
  \item{clab}{character size of axes labels to be passed to
          \code{par("cex.lab")}}
  \item{errbar}{a character string.  Type of error bars: either
    \code{"CI"} for confidence intervals or \code{"SE"} for standard
    errors}
  \item{alpha}{the alpha-level for the tests}
  \item{draw}{logical. If \code{FALSE}, no plot is drawn}
  \item{\dots}{further arguments to be passed to the function
    \code{plot.wi}}
}
\value{
  The function returns a list of objects of class \code{wiII} or
  \code{wiIII} (one component per animal).
}
\references{
  Manly B.F.J., McDonald L.L., Thomas, D.L., McDonald, T.L. & Erickson,
  W.P. (2003) \emph{Resource selection by animals - Statistical design and
    Analysis for field studies. Second edition}.
  London: Kluwer academic publishers.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{\code{\link{widesII}} and \code{\link{widesIII}} for further
  information on objects of class \code{wiII} and \code{wiIII},
  \code{\link{as.sahrlocs}} for further information on objects of class
  \code{sahrlocs}.}

\examples{
data(puechabon)
sahr <- puechabon$sahr
toto <- plot(sahr)






### Note that the wild boars named Brock and Calou
### have only one herbaceous cover class available
### (the second one), and they use it exclusively.
### So they have identical
### selection ratios (that's why the curve of Brock
### does not appear: it is hidden behind the curve
### of the boar named Calou).

toto
toto$Elevation

}
\keyword{hplot}
\keyword{math}

\eof
\name{predict.enfa}
\alias{predict.enfa}
\title{Habitat Suitability Maps Built from the ENFA}
\description{
  \code{predict.enfa} computes habitat suitability maps using the
  Ecological-Niche Factor Analysis and the Mahalanobis distances
  method.
}
\usage{
predict.enfa(object, nf, \dots)
}
\arguments{
  \item{object}{an object of class \code{enfa}}
  \item{nf}{the number of axes of specialization kept for the
    predictions.  By default, all axes kept in \code{object} are
    used}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
The predictions are based on the position of the niche defined by the
ENFA within the multidimensional space of environmental variables.  The
ENFA produces row coordinates for each pixel, which are used with the
function \code{mahalanobis}.  For each pixel, this function computes the
Mahalanobis distances from the barycentre of the niche.\cr

Actually, the function \code{predict.enfa} is identical to the function
\code{mahasuhab}, except that the habitat suitability map is computed
using the axes of the ENFA, instead of the raw data.
}
\value{
Returns a raster map of class \code{kasc}.
}
\references{
  Clark, J.D., Dunn, J.E. and Smith, K.G. (1993) A multivariate model of
  female black bear habitat use for a geographic information
  system. \emph{Journal of Wildlife Management}, \bold{57}, 519--526.

  Hirzel, A.H., Hausser, J., Chessel, D. & Perrin, N. (2002)
  Ecological-niche factor analysis: How to compute habitat-suitability
  maps without absence data? \emph{Ecology}, \bold{83}, 2027--2036.  
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr}}
\seealso{
\code{\link[stats]{mahalanobis}} for information on the computation of
Mahalanobis distances.  \code{\link{mahasuhab}} for more details on the
computation of habitat suitability maps using the Mahalanobis distances. 
}
\examples{
\dontrun{
data(lynxjura)

## We keep only "wild" indices.
tmp <- lynxjura$loc[,4] != "D"
map <- lynxjura$map
pts <- lynxjura$locs[tmp, c("X","Y")]
(enfa1 <- enfa(map, pts, scannf = FALSE))

## Compute the prediction
pred <- predict(enfa1)
image(pred)
contour(pred, col="green", add=T)
points(pts, col = "red", pch = 16)
## Lighter areas are the most preferred areas
}
}
\keyword{multivariate}

\eof
\name{puechabon}
\docType{data}
\alias{puechabon}
\title{ Radio-Tracking Data of Wild Boar }
\description{
This data set stores the results of the monitoring of 4 wild boars at
Puchabon (Mediterranean habitat, South of France).
These data have been collected by Daniel Maillard (Office national de la
chasse et de la faune sauvage).
}
\usage{
data(puechabon)
}
\details{
  The list \code{puechabon} has three components:\cr
  \code{puechabon$kasc}
  is an  object of class \code{kasc} (see \code{help(as.kasc)}) that
  describes several variables on the study area.\cr
  \code{locs} is a data frame of the relocations of the wild boar
  resting sites in summer. Information on
  wild boars is provided by factors \code{Name}, \code{Sex}, \code{Age}.\cr
  \code{sahr} is the associated object of class
  \code{sahrlocs}.  The home ranges were 
  estimated with buffers including all pixels within 500 m of a boar
  relocation.
}
\references{
Maillard, D. (1996). \emph{Occupation et utilisation de la garrigue et
  du vignoble mditerranens par le Sanglier}.
Universit d'Aix-Marseille III: PhD thesis.
}

\keyword{datasets}

\eof
\name{puechcirc}
\alias{puechcirc}
\docType{data}
\title{Movements of wild boars tracked at Puechabon}
\description{
This data set is an object of class \code{traj}, giving the results of the
monitoring of 2 wild boars by radio-tracking at Puchabon (Mediterranean
habitat, South of France).  These data have been
collected by Daniel Maillard (Office national de la chasse et de la
faune sauvage), and correspond to the activity period of the wild boar
(during the night, when the animals forage. The data set
\code{puechabon} describes the resting sites). 
}
\usage{data(puechcirc)}
\format{
  This data frame has 204 observations, and 5 variables:
  \describe{
    \item{id}{a factor with levels \code{CH93} and \code{JE93}, giving the
      name of the animals}
    \item{x}{a vector giving the x coordinates of the relocations}
    \item{y}{a vector giving the y coordinates of the relocations}
    \item{date}{a POSIXct giving the date of collection of the relocations}
    \item{burst}{a factor with levels \code{CH930803}, \code{CH930824},
      \code{CH930827}, \code{JE930819}, and \code{JE930827}, giving the
      ID of the circuits.}
  }
}
\source{
Maillard, D. (1996). \emph{Occupation et utilisation de la garrigue et
  du vignoble mditerranens par le Sanglier}.
Universit d'Aix-Marseille III: PhD thesis.
}
\keyword{datasets}

\eof
\name{puechdesIII}
\alias{puechdesIII}
\docType{data}
\title{Habitat Selection by the Wild Boar at Puechabon}
\description{
This data set contains two data frames describing the use and the
availability of 3 elevation classes for 6 wild boars (\emph{Sus scrofa}
L.) monitored using radio-tracking at Puchabon (South of France).
These data have been collected by Daniel Maillard (Office national de la
chasse et de la faune sauvage).
}
\usage{data(puechdesIII)}
\details{
  The list \code{puechdesIII} has two components: \cr
  The data frame \code{used} describes the number of telemetry
  relocations  for each of the 6 animals in each of the three elevation
  classes. \cr
  The data frame \code{available} describes a sample 
  of random points placed in the areas available to these wild boars 
  (a buffer area of 200 m around the relocations).
}
\source{
Maillard, D. (1996) \emph{Occupation et utilisation de la garrigue et du
vignoble mditerranens par le Sanglier}.
Universit d'Aix-Marseille III:  PhD thesis.
}
\keyword{datasets}

\eof
\name{rand.kselect}
\alias{rand.kselect}
\alias{print.rand.kselect}
\title{Test of the Third-Order Habitat Selection }
\description{
  \code{rand.kselect} tests whether the marginality vector of animals
  is significantly larger than what is expected under the hypothesis of
  random habitat use (third-order habitat selection:
  selection by the animals of the relocations within their home range;
  the habitat availability is measured for each animal).  The effect of
  each variable  on individual marginality is also tested. 
  Finally, the pertinence of a K-select analysis is also tested.  This is
  a randomisation test.  The alpha-level of the tests is
  ajusted using the Bonferroni inequality.
}
\usage{
rand.kselect(dudi, factor, weight, nrep = 200, alpha = 0.05, ewa = FALSE)
print.rand.kselect(x, \dots)
}
\arguments{
  \item{dudi}{an object of class \code{dudi}.}
  \item{factor}{a factor defining the animals identity}
  \item{weight}{a weight vector of integer values (number of relocations
    counted in each resource unit in row of the object dudi)}
  \item{nrep}{the number of repetitions of the test}
  \item{alpha}{the alpha level for the tests.}
  \item{ewa}{logical. If \code{TRUE}, uniform weights are given
    to all animals in the analysis. If \code{FALSE}, animal weights are
    given by the proportion of relocations of each animal (i.e. an
    animal with 10 relocations has a weight 10 times lower than an
    animal with 100 relocations)}
  \item{x}{an object of the class \code{rand.kselect}.}
  \item{\dots}{further arguments to be passed to the generic function 
     \code{print}}
}
\details{
  This test is carried out by simulating a random use of space by
  animals. \code{rand.kselect} is closely related to the function
  \code{kselect} (same  arguments). 

  At each step  of the randomisation procedure, and for each
  animal, the test randomly allocates the nk relocations (where nk is the
  sum of the weight vector for the animal k) in the Ik pixels available
  to this animal (where Ik is the length of the weight vector for animal
  k).

  The length of the marginality vector is 
  recomputed at each step of the randomisation procedure and for each
  animal. The effect of each variable on the use of pixels by each
  animal is measured by the criterion "(average habitat variable j
  used by animal i) minus (average habitat variable j available to
  animal i)". Finally the value of the first eigenvalue of the 
  K-select analysis provides a criterion to test the pertinence of the
  K-select analysis. 
  
  All these values are then compared to the observed values to assess
  the significance of theses effects.
}
\value{
  Returns an object of class \code{rand.kselect}. This list has three
  components: 
  \item{ global }{a vector of length 2 
    giving the results of the randomisation procedure for the first
    eigenvalue of the K-select analysis.}
  \item{ marg }{a matrix giving the significance of the marginality of
    each animal.} 
  \item{ per.ind }{a list giving the results of the randomisation test for the 
    coordinates of the marginality vector for each animal
    on each habitat variable.}
  \item{ alpha }{the alpha level of the tests.}
}
\references{
  Calenge, C., Dufour, A.B. and Maillard,
  D. (\emph{submitted}). K-select analysis, a new method to analyse
  habitat selection in radio-tracking studies.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{kselect}} to perform a K-select analysis. }

\examples{
\dontrun{
## Loads the data
data(puechabon)
sahr <- puechabon$sahr

## prepares the data for the kselect analysis: only two variables are kept
x <- sahrlocs2kselect(sahr)
tab <- x$tab
dud <- dudi.mix(tab, scannf = FALSE, nf = 2)

## the randomisation tests
## be patient, this can be very long on some machines
(te <- rand.kselect(dud, x$factor, x$weight, nrep = 50))

}
}
\keyword{multivariate}

\eof
\name{randtest.enfa}
\alias{randtest.enfa}
\title{Randomisation Test for the Ecological Niche Factor Analysis }
\description{
\code{randtest.enfa} performs a randomisation test for the Ecological
Niche Factor analysis (ENFA).
}
\usage{
randtest.enfa(xtest, nrepet = 999, \dots)
}
\arguments{
  \item{xtest}{an object of class \code{enfa}}
  \item{nrepet}{the number of iterations for the randomisation test}
  \item{\dots}{further arguments to be passed to the generic function
    \code{randtest}}

}
\details{
  This test is carried out by simulating a random distribution of the
  species occurrences in the pixels of a map.

  At each step  of the randomisation procedure, the test randomly
  allocates the nk occurrences (where nk is the 
  sum of the occurrence vector \code{pr} of the object of class \code{enfa})
  in the Ik pixels of the focus area (where Ik is the length of this occurrence
  vector).

  At each step of the procedure, the first eigenvalue of the ENFA
  performed on the randomised data set is recomputed. This
  value provides a criterion to test the pertinence of the ENFA
  analysis.
}
\value{
  returns a list of class \code{randtest}
}
\references{
  Manly, B.F.J. (1997) \emph{Randomization, Bootstrap and Monte Carlo
    Methods in Biology}. London: Chapman & Hall.
  
  Hirzel, A.H., Hausser, J., Chessel, D. and Perrin, N. (2002)
  Ecological-niche factor analysis: How to compute habitat suitability
  maps without absence data? \emph{Ecology}, \bold{83}, 2027--2036.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}
}
\seealso{\code{\link{enfa}}}
\examples{
\dontrun{
data(chamois)
locs <- chamois$locs
map <- chamois$map
map$Vegetation <- NULL
en <- enfa(map, locs, scannf=F)
(tutu <- randtest(en))
plot(tutu)
}
}
\keyword{multivariate}

\eof
\name{rotxy}
\alias{rotxy}
\alias{.buffer.point.unic}
\alias{profilehab}
\alias{[.kasc}
\alias{[[.kasc}
\title{ Internal Functions for Package 'adehabitat' }
\description{
Internal functions for the package \code{adehabitat}.
}
\usage{
}

\details{
These are not to be called by the user.
}
\keyword{internal}

\eof
\name{sahrlocs2kselect}
\alias{sahrlocs2kselect}
\title{Preparation of K-Select Analysis}
\description{
  \code{sahrlocs2kselect} converts an object of class sahrlocs into a
  list that contains the arguments needed for a kselect analysis (see
  \code{help(kselect)}).
}
\usage{
sahrlocs2kselect(sahr)
}
\arguments{
  \item{sahr}{an object of class \code{sahrlocs}}
}
\value{
  Returns a list with the following components:
  \item{tab}{a data frame giving the habitat composition of the home range of
    animals}
  \item{factor}{a factor giving for each row of \code{tab} the name of the
    corresponding animal}
  \item{weight}{a numeric vector giving for each row of \code{tab} the number
    of relocations numbered in this cell of the raster map}
}
\references{
  Calenge, C., Dufour, A.B. and Maillard,
  D. (\emph{submitted}). K-select analysis, a new method to analyse
  habitat selection in radio-tracking studies.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{as.sahrlocs}} for additional information on the
  objects of class \code{sahrlocs}, \code{\link{kselect}} for a K-select
  analysis, and \code{\link{kasc2df}} for additional information on
  the index component of the output.} 

\examples{
data(puechabon)
sahr <- puechabon$sahr
s <- sahrlocs2kselect(sahr)

# 1. PCA of the dataset
pc <- dudi.mix(s$tab, scannf = FALSE)

# 2. k-select analysis
kn <- kselect(pc, s$factor, s$weight, scannf = FALSE)


scatter(kn)
}
\keyword{multivariate}



\eof
\name{sahrlocs2niche}
\alias{sahrlocs2niche}
\title{OMI Analysis of Radio-Tracking Data}
\description{
  \code{sahrlocs2niche} converts an object of class \code{sahrlocs} into a
  list that contains the arguments needed for a niche analysis
  (function \code{\link[ade4]{niche}} in package \code{ade4}).
}
\usage{
sahrlocs2niche(x, ani = names(x$hr), var = names(x$sa), used = c("hr",
"locs")) 
}
\arguments{
  \item{x}{an object of class \code{sahrlocs}.}
  \item{ani}{a character vector giving the name of the animals in the
    analyses}
  \item{var}{a character vector giving the name of the variables in the
    analyses}
  \item{used}{a character string.  If \code{"hr"}, the cells of the raster
    map that are considered used by the animals are taken from the
    \code{hr} component of the object \code{sahrlocs}, if \code{"locs"},
    the cells of the raster map that are considered used by the animals
    are taken from the \code{locs} component (see
    \code{\link{as.sahrlocs}}))
  }
}
\value{
  Returns a list with three components:
  \item{index}{a vector of integer giving the index of the rows of
    \code{x$sa} kept for the analysis (this component may then be used
    with the function \code{\link{df2kasc}}).}
  \item{tab}{the table on which the \code{dudi} analysis will be processed.}
  \item{y}{a table giving the weights of the niche analysis.}
}
\references{Doldec, S., Chessel, D. and Gimaret, C. (2000) Niche
  separation in community analysis: a new method. \emph{Ecology}, \bold{81},
  2914--1927.}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }

\seealso{\code{\link{as.sahrlocs}} for additional information on the
  objects of class \code{sahrlocs}, \code{\link[ade4]{niche}} for an
  OMI analysis, and \code{\link{kasc2df}} for additional information on
  the \code{index} component of the output. }

\examples{
data(puechabon)
sahr <- puechabon$sahr

s <- sahrlocs2niche(sahr, used = "locs")


# 1. dudi.mix of the dataset
pc <- dudi.mix(s$tab, scannf = FALSE)

# 2. niche analysis
n <- niche(pc, s$y, scannf = FALSE)

plot(n)
}
\keyword{multivariate}

\eof
\name{scatter.enfa}
\alias{scatter.enfa}
\title{Scatter Plot of the Results of the ENFA}
\description{
Performs the scatter diagrams of objects of class \code{enfa}.
}
\usage{
scatter.enfa(x, xax = 1, yax = 2, h, pts = FALSE,
             ncont = 1, clabel = 1, colZ = "blue",
             colS = "orange", lwdZ = 2, lwdS = 3,
             side = c("top", "bottom", "none"),
             csub = 1, ...)
}
\arguments{
  \item{x}{an object of class \code{enfa}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{h}{vector of bandwidths for x and y directions, used in the
    function \code{kde2d} of the package \code{MASS}.  Defaults to
    normal reference bandwidth (see \code{?kde2d})}
  \item{pts}{logical. Whether the points should be drawn.  If
    \code{FALSE}, contours of kernel densities estimates are displayed}
  \item{ncont}{if \code{pts == FALSE}, an integer indicating the number
    of contour levels desired for the kernel densities estimates.  By
    default, only the external one is displayed}
  \item{clabel}{a character size for the columns}
  \item{colZ}{color for the kernel density estimates of the available
    pixels}
  \item{colS}{color for the kernel density estimates of the used
    pixels}
  \item{lwdZ}{if \code{pts==FALSE}, the line width for the kernel
    density estimates of the available pixels}
  \item{lwdS}{if \code{pts==FALSE}, the line width for the kernel
    density estimates of the used pixels}
  \item{side}{if \code{"top"}, the legend of the kept axis is upside, if
    \code{"bottom"} it is downside, if \code{"none"} no legend}
  \item{csub}{a character size for the legend}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
\code{scatter.enfa} displays a factorial map of pixels, as well as the
projection of the vectors of the canonical basis multiplied by a
constant of rescaling.
The kept axes for the plot are specified in a corner.
}
\author{Mathieu Basille \email{basille@biomserv.univ-lyon1.fr}}
\section{Warning}{
 \code{biv.test} uses the function \code{kde2d} of the package \code{MASS}.
}
\seealso{\code{\link{enfa}}, \code{\link[ade4]{scatter}}}
\examples{
\dontrun{
data("lynxjura")

## We keep only "wild" indices.
tmp=lynxjura$loc[,4]!="D"

if (require(MASS))
    scatter(enfa(lynxjura$map, lynxjura$locs[tmp, c("X", "Y")],
            scannf=FALSE, nf=3))
}
}
\keyword{multivariate}
\keyword{hplot}

\eof
\name{setmask}
\alias{setmask}
\title{Applies a Mask on Objects of Class 'asc' or 'kasc'}
\description{
  Applies a mask on objects of class \code{asc} or \code{kasc}. In other
  words, the function creates an object of class \code{asc} or
  \code{kasc}, with \code{NA} for all pixels \code{NA} on the masking map.
}
\usage{
setmask(x, mask)
}
\arguments{
  \item{x}{an object of class \code{asc} or \code{kasc}}
  \item{mask}{an object of class \code{asc}}
}
\value{
  Returns an object of class \code{asc} or \code{kasc}
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{ \code{\link{import.asc}} for additionnal information on
  objects of class \code{asc}. }

\examples{

data(puechabon)
kasc <- puechabon$kasc
image(kasc)
elev <- getkasc(kasc, "Elevation")
slope <- getkasc(kasc, "Slope")

## ma is the mask: only areas with elevation > 250 m
## are kept
ma <- elev
ma[ma < 250] <- NA
ma <- getascattr(elev, ma)
image(ma)

## The mask is applied on maps of slope
slp <- setmask(slope, ma)
image(slp)

## The mask is applied on all maps in kasc
im <- setmask(kasc, ma)
image(im)

}
\keyword{spatial}


\eof
\name{speed}
\alias{speed}
\title{Computes the Speed Between Successive Relocations of an Animal }
\description{
  \code{speed} measures the speed between successive relocations of
  animals, using objects of class \code{traj}.
}
\usage{
speed(x, id = levels(x$id), burst = levels(x$burst), date = NULL,
      units = c("seconds", "hours", "days"))
}
\arguments{
  \item{x}{an object of class \code{traj}}
  \item{id}{a character vector giving the identity of the animals for
    which the speed is to be computed}
  \item{burst}{a character vector giving the identity of the circuits
    for which the speed is to be computed (see \code{as.traj})}
  \item{date}{a vector of class \code{POSIXct} of length 2 (beginning, end)
    delimiting the period of interest}
  \item{units}{a character string. It determines how the
    speeds are computed.  For example, if the coordinates are given in
    meters, and if \code{units = "seconds"}, speeds are returned in
    meters per second.}
}
\value{
  Returns a data frame with the following components:
  \item{id}{the identity of the animal}
  \item{x}{if the speed is computed between the relocation 1 and 2,
    the x coordinate of the relocation 2.}
  \item{y}{if the speed is computed between the relocation 1 and 2,
    the y coordinate of the relocation 2.}
  \item{date}{a vector of class \code{POSIXct}, giving the date of
    relocation 2.}
  \item{burst}{the identity of the circuit}
  \item{sp.x}{the computed speed of the animal in the x direction}
  \item{sp.y}{the computed speed of the animal in the y direction}
  \item{speed}{the computed speed of the animal on the plane.}
  \item{dt}{the duration between the two relocations (in the units given
  by the parameter \code{units}).}
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{as.traj}}}
\examples{

#### Computes the speed for each wild boar
#### monitored at Puechabon
data(puechcirc)
puechcirc
plot(puechcirc)
sp <- speed(puechcirc)
sp[1:4,]

}
\keyword{spatial}


\eof
\name{squirrel}
\docType{data}
\alias{squirrel}
\title{Radio-Tracking Data of Squirrels}
\description{
This data set describes the use and availability of 5 habitat types for
17 squirrels monitored using radio-tracking. 
}
\usage{data(squirrel)}
\format{
  This list has three components: \describe{
    \item{\code{studyarea}}{a data frame giving the proportion of each
      habitat type (columns) on the study area. These proportions are
      repeated by rows, for all animals}
    \item{\code{mcp}}{a data frame giving the proportion of
      each habitat type (columns) in the home range of each animal (rows)}
    \item{\code{locs}}{a data frame giving the proportion of relocations
      of each animal (rows) reported in each habitat type (columns).}
    }
}
\source{
  Aebischer, N. J., Robertson, P. A. and Kenward, R. E. (1993)
  Compositional analysis of habitat use from animal radiotracking
  data. \emph{Ecology}, \bold{74}, 1313--1325.
}
\keyword{datasets}

\eof
\name{storemapattr}
\alias{storemapattr}
\title{Store attributes of maps of class asc and kasc}
\description{
  \code{storemapattr} stores attributes of maps of class \code{asc} and
  \code{kasc} in an object of class \code{mapattr}. 
}
\usage{
storemapattr(x)
}
\arguments{
  \item{x}{ An object of class \code{asc} or \code{kasc} }
}
\details{
  This function is essentially used by programmers in functions dealing with
  maps of class \code{asc} or \code{kasc}.  The function
  \code{getXYcoords} is an example of function using \code{storemapattr}.
}
\value{
  Returns an object of class \code{mapattr}.
}
\author{ Clment Calenge \email{calenge@biomserv.univ-lyon1.fr} }
\seealso{ \code{\link{as.kasc}} and \code{\link{import.asc}} for
  additional information on the classes \code{kasc} and \code{asc}. }
\examples{
data(puechabon)
(kasc <- puechabon$kasc)

(toto <- storemapattr(kasc))

}
\keyword{programming}

\eof
\name{subsetmap}
\alias{subsetmap}
\alias{subsetmap.asc}
\alias{subsetmap.kasc}
\title{Storing a Part of a Map}
\description{
  \code{subsetmap} is a generic function.  It has methods for the classes
  \code{asc} and \code{kasc}.  It is used to store a part of any given
  map into an other object.
}
\usage{
subsetmap(x, xlim = NULL, ylim = NULL, ...)
}
\arguments{
  \item{x}{an object of class \code{asc} or \code{kasc}}
  \item{xlim}{numerical vector of length 2.  The x limits of the rectangle
    including the new map}
  \item{ylim}{numerical vector of length 2.  The y limits of the rectangle
    including the new map}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
  If \code{xlim} or \code{ylim} are not provided, the function asks the
  user to click on the map to delimit the lower left corner and the
  higher right corner of the new map (see Examples).
}
\value{
  Returns an object of class \code{asc} or \code{kasc}
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}
\seealso{\code{\link{as.asc}}, \code{\link{as.kasc}}}
\examples{

data(puechabon)
kasc <- puechabon$kasc
el <- getkasc(kasc, "Elevation")

## limits of the new map:
xl <- c(701561, 704017)
yl <- c(3160560, 3162343)

## computation of the new map:
su <- subsetmap(el, xlim = xl, ylim = yl)

## Display
opar <- par(mar = c(0,0,0,0))
layout(matrix(c(1,1,1,1,1,1,1,1,2), byrow = TRUE, ncol = 3))
image(el, axes = FALSE)
polygon(c(xl[1], xl[2], xl[2], xl[1]),
        c(yl[1], yl[1], yl[2], yl[2]))
image(su, axes = FALSE)
box()

par(opar)
par(mfrow = c(1,1))

### Gets this part for the whole kasc object
m <- subsetmap(kasc, xlim = xl, ylim = yl)
image(m)


\dontrun{
 ## Interactive example 
 su <- subsetmap(kasc)

 image(su)
}

}
\keyword{spatial}

\eof
\name{vanoise}
\docType{data}
\alias{vanoise}
\title{Habitat Use by Three Species of Galliformes in the Vanoise
  National Parc}
\description{
  This data frame describes the habitat use by the Black Grouse
  (\emph{Tetrao tetrix}), the Rock Partridge (\emph{Alectoris graeca})
  and the Rock Ptarmigan (\emph{Lagopus mutus}), in the Vanoise National
  Park (French Alps), from 1990 to 2000.
}
\usage{data(vanoise)}
\format{
  This data frame has 3110 rows and eight columns describing the habitat
  composition 
  for each occurrence of three species of Galliformes. For each
  located occurrence (in rows), the employees of the national park have noted:
  the species, the elevation (in metres), the aspect (8 classes), the
  habitat type (7 categories, \code{FR} means "fallen rocks") and the
  date (season, day, month and year).
}
\source{
  Calenge, C., Martinot, J.P. and Lebreton, P. (2003)
  Ecological niche separation among mountain Galliformes in the Vanoise
  National Parc. \emph{Game and Wildlife Science}, 20, 259-285.
}
\keyword{datasets}

\eof
\name{wi}
\alias{widesI}
\alias{widesII}
\alias{widesIII}
\alias{print.wiI}
\alias{print.wiII}
\alias{print.wiIII}
\alias{plot.wi}
\alias{wi}
\alias{wiI}
\alias{wiII}
\alias{wiIII}
\title{Computation of Selection Ratios for Habitat Selection Studies.}
\description{
  These functions compute the resource selection ratios (wi) for design I, II
  and III data types, with resources defined by several categories.
  Basic tests are also provided.
}
\usage{
widesI(u, a, avknown = TRUE, alpha = 0.05)
widesII(u, a, avknown = TRUE, alpha = 0.05)
widesIII(u, a, avknown = TRUE, alpha = 0.05)
print.wiI(x, \dots)
print.wiII(x, \dots)
print.wiIII(x, \dots)
plot.wi(x, caxis = 0.7, clab = 1, ylog = FALSE, errbar = c("CI", "SE"),
        main = "Manly selectivity measure", noorder = TRUE, \dots)
}
\arguments{
  \item{u}{for \code{widesI}, a vector with named elements describing
    the sample of used resource units.  For \code{widesII} and
    \code{widesIII} a matrix or a data frame giving the number of used
    resource units for each animal (in rows) in each resource category
    (in columns)}
  \item{a}{for \code{widesI} and \code{widesII}, a vector with named
    elements describing the sample or the proportion of available
    resource units.  For \code{widesIII} a matrix or a
    data frame giving the number or the proportion of available resource
    units for each animal (in rows) in each resource category (in
    columns)}
  \item{avknown}{logical. \code{TRUE} if the available
    proportions are known, and \code{FALSE} if they are estimated}
  \item{alpha}{the threshold value for the tests and confidence
    intervals}
  \item{x}{an object of class \code{wi}}
  \item{caxis}{character size on axes to be passed to
    \code{par("cex.axis")}}
  \item{clab}{character size of axes labels to be passed to
    \code{par("cex.lab")}}
  \item{ylog}{logical.  If \code{TRUE}, the selection ratios are plotted
    on a log scale}
  \item{errbar}{a character string.  Type of error bars: either \code{"CI"}
    for confidence intervals or \code{"SE"} for standard errors}
  \item{main}{a character string. The title of the graph}
  \item{noorder}{logical. If \code{TRUE}, the habitat categories are
    ordered on the graph in decreasing order of their preference. If
    FALSE, they are not ordered (i.e. they are in the same order as the
    columns in \code{used} and \code{available}}
  \item{\dots}{additionnal arguments to be passed to the function
    \code{plot}} 
}
\details{
  \code{widesI} may be used to explore resource selection by
  animals, when designs I are involved (habitat use and availability are
  measured at the population level - animals are not identified).  The
  function tests habitat selection with the Khi2 of Pearson
  and log-likelihood Khi2 (recommended, see Manly et al. 2003).  The
  Manly selectivity measure (selection ratio = used/available) is
  computed, the preference / avoidance is tested for
  each habitat, and the differences between selection ratios are computed
  and tested. \cr

  \code{widesII} computes the selection ratios with design II
  data (same availability for all animals, but use measured for each one).
  Tests of identical habitat use for all animals, and of habitat
  selection are also provided.\cr

  \code{widesIII} computes the
  selection ratios for design III data (when the use and the
  availability are measured for each animal - 
  see examples on the wild boar below).  Habitat selection is tested
  using a Chi-square for each animal, and the overall habitat selection
  is also tested.
}
\value{
  \code{widesI} returns a list of the class \code{wiI}.  \code{widesII}
  returns a list of class \code{wiII}.  \code{widesIII}
  returns a list of class \code{wiIII}.  These objects are all
  inheriting from the class \code{wi}.  They have the following components:
  \item{used.prop}{the proportion of use for each resource type.}
  \item{avail.prop}{the proportion of available resources.}
  \item{wi}{the Manly selectivity measure (selection ratio:
    used/available).}
  \item{se.wi}{the standard error of the selection ratios.}
  \item{comparisons}{a list with the following components:\describe{
    \item{\code{diffwi}}{a matrix with the differences of the selection
      ratios for each pair of resource type.}
    \item{\code{ICdiffupper}}{a matrix containing the upper limit of confidence
      interval on the differences of the selection ratios between each
      pair of resource type.}
    \item{\code{ICdifflower}}{a matrix containing the lower limit of confidence
      interval on the differences of the selection ratios between each
      pair of resource type.}
    \item{\code{signif}}{the ranking matrix, with the sign of the differences
      between the resource type in row and the resource type in
      column.  When the difference is significant, the sign is
      tripled.}
    }
  }
  \item{profile}{the profile of preferences: resource types are sorted
    so that the left type is the most preferred and the right type is
    the most avoided.  Habitats for which the selection ratios are not
    significant are connected by a line.}
  \item{alpha}{the parameter \code{alpha} of this function.}
  \item{avknown}{the parameter \code{avknown} of this function.}
  \item{se.used}{only for designs I, the standard error of
    the proportion of use.}
  \item{se.avail}{only for designs I, the standard error of
    the available proportion.}
  \item{chisquwi}{only for designs I, the results of Chi-Square tests of the
    hypothesis that the selection ratios are in average equals to zero.}
  \item{Bi}{only for designs I, equals to \code{wi/sum(wi)}.}
  \item{Khi2P}{only for designs I, test of random resource use (Pearson
    statistic).}
  \item{Khi2L}{only for designs I, test of random resource use
    (Log-likelihood statistic).}
  \item{Khi2L1}{only for designs II, test of identical use of habitat by all
    animals.}
  \item{Khi2L2}{only for designs II, test of overall habitat selection.}
  \item{Khi2L2MinusL1}{only for designs II, test of hypothesis that animals
    are on average using resources in proportion to availability,
    irrespective of whether they are the same or not (= Khi2L2 -
    Khi2L1).}
  \item{wij}{only for designs II and III, a matrix with the selection
    ratios for all animals and all resource categories.}
  \item{ICwiupper}{only for designs II and III, the upper limit of the
    confidence intervals on the selection ratios.}
  \item{ICwilower}{only for designs II and III, the lower limit of the
    confidence intervals on the selection ratios.}
  \item{Khi2Lj}{only for designs III, the test of habitat selection for each
    animal.}
  \item{Khi2L}{only for designs III, the global test of overall habitat
    selection.}
}
\references{
  Manly B.F.J., McDonald L.L., Thomas, D.L., McDonald, T.L. & Erickson,
  W.P. (2003) \emph{Resource selection by animals - Statistical design and
    Analysis for field studies. Second edition}
  London: Kluwer academic publishers.

  Thomas D. L. and Taylor E. J. (1990) Study designs and tests for
  comparing resource use and availability. \emph{Journal of Wildlife
  Management}, \bold{54}, 322--330.
}
\author{Clment Calenge \email{calenge@biomserv.univ-lyon1.fr}}

\seealso{\code{\link{compana}} for another analysis with this kind of
  data.} 

\examples{

############################
## Example of moose (Manly et al., 2003, p.52)
## Known available proportions on design I data
moose.avail <- c(0.34, 0.101, 0.104, 0.455)
moose.used <- c(25, 22, 30, 40)
names(moose.used) <- c("InBurnInterior",
                     "InBurnEdge",
                     "OutOfBurnEdge",
                     "OutOfBurnFurther")
names(moose.avail) <- names(moose.used)
## Computation of wi
(wiRatio <- widesI(moose.used, moose.avail))

## plot the values of the selection ratios
opar <- par(mfrow=c(2,2))
plot(wiRatio)

par(opar)




############################
## Example of Elk (Manly et al., 2003, p.62)
## Estimated available proportions on design I data
elk.avail <- c(15, 61, 84, 40)
elk.used <- c(3, 90, 181, 51)
names(elk.used) <- c("0\%", "1-25\%", "26-75\%", ">75\%")
names(elk.avail) <- names(elk.used)
## Computation of wi
(wiRatio <- widesI(elk.used, elk.avail, avknown=FALSE))

## plot the values of the selection ratios
opar <- par(mfrow=c(2,2))
plot(wiRatio)

par(opar)




############################
## Example of Bighorn (Manly et al., 2003, p.67)
## Known available proportions on design II data
data(bighorn)
## Computation of wi
(wi <- widesII(bighorn$used, bighorn$availT, alpha = 0.1))

## plot the values of the selection ratios
opar <- par(mfrow=c(2,2))
plot(wi)



############################
## Example of Bighorn (Manly et al., 2003, p.74)
## Estimated available proportions on design II data
## Computation of wi
(wi <- widesII(bighorn$used, bighorn$availE, avknown = FALSE, alpha = 0.1))

## plot the values of the selection ratios
plot(wi)

par(opar)


############################
## Example of Wild boar
## Estimated available proportions on design III data
data(puechdesIII)
used <- puechdesIII$used
available <- puechdesIII$available

## calculation of the selectio ratios
## with sampled availability
(i <- widesIII(used,available, avknown = FALSE, alpha = 0.1))

opar <- par(mfrow = c(2,2))
plot(i)

par(opar)


}
\keyword{hplot}
\keyword{math}

\eof
